/****************************************************************************
 *
 *  Rohde & Schwarz RTM Oscilloscope instrument driver include file
 *
 ****************************************************************************/

#ifndef __RSRTM_HEADER
#define __RSRTM_HEADER

#include "rsidr_core.h"
#include "rsrtm_attributes.h"
#include "rsrtm_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/
#define RSRTM_SIMULATION_ID_QUERY      "Rohde&Schwarz,RTM,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSRTM_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSRTM_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSRTM_IO_BUFFER_SIZE           1024L   /* I/O buffer size */
#define RSRTM_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
#define IEEE_488_2_ERROR_MASK             0x4    /* 488.2 STB Bits */   
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */
#define RSRTM_NAN                 9.91e+37

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSRTM_CLASS_DRIVER_DESCRIPTION           ""
#define RSRTM_CLASS_DRIVER_PREFIX                ""
#define RSRTM_CLASS_DRIVER_VENDOR                ""
#define RSRTM_CLASS_DRIVER_REVISION              ""
#define RSRTM_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSRTM_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSRTM_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSRTM_SPECIFIC_DRIVER_PREFIX             "RSRTM"
#define RSRTM_SPECIFIC_DRIVER_LOCATOR            ""
#define RSRTM_SPECIFIC_DRIVER_VENDOR             ""
#define RSRTM_MAJOR_VERSION                      4L    /* Instrument driver major version          */
#define RSRTM_MINOR_VERSION                      60L    /* Instrument driver minor version          */
#define RSRTM_MINOR_MINOR_VERSION                3L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSRTM_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSRTM_GROUP_CAPABILITIES                 ""
#define RSRTM_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSRTM_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSRTM_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSRTM_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSRTM_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSRTM_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSRTM_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSRTM_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSRTM_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define RSRTM_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define RSRTM_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSRTM_ERROR_CODES_AND_MSGS \
    {RSRTM_WARN_MEASURE_UNCALIBRATED,  RSRTM_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSRTM_WARN_OVER_RANGE,            RSRTM_WARNMSG_OVER_RANGE},\
    {RSRTM_ERROR_MARKER_NOT_ENABLED,   RSRTM_ERRMSG_MARKER_NOT_ENABLED},\
    {RSRTM_ERROR_NOT_DELTA_MARKER,     RSRTM_ERRMSG_NOT_DELTA_MARKER},\
    {RSRTM_ERROR_MAX_TIME_EXCEEDED,    RSRTM_ERRMSG_MAX_TIME_EXCEEDED}


/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSRTM_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSRTM_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSRTM_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSRTM_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSRTM_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSRTM_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSRTM_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSRTM_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSRTM_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSRTM_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSRTM_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSRTM_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSRTM_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSRTM_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSRTM_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSRTM_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSRTM_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSRTM_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSRTM_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSRTM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSRTM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSRTM_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSRTM_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSRTM_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSRTM_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSRTM_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSRTM_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSRTM_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSRTM_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSRTM_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSRTM_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME

/* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSRTM_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSRTM_ATTR_ACQUISITION_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSRTM_ATTR_WAVEFORM_ACQUISITION_TYPE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSRTM_ATTR_FILTER_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 613
#define RSRTM_ATTR_INTERPOLATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSRTM_ATTR_NUM_AVERAGES                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSRTM_ATTR_NUMBER_OF_WAVEFORMS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 614
#define RSRTM_ATTR_SAMPLE_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSRTM_ATTR_WAVEFORM_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define RSRTM_ATTR_HORZ_TIME_PER_RECORD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSRTM_ATTR_HORZ_RECORD_LENGTH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 667
#define RSRTM_ATTR_HORZ_SCALE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSRTM_ATTR_ACQUSITION_START_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSRTM_ATTR_ACQUISITION_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSRTM_ATTR_HORZ_ADC_SAMPLE_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSRTM_ATTR_HORZ_SAMPLE_RATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 610
#define RSRTM_ATTR_AUTOSCALE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSRTM_ATTR_HORZ_DIVISIONS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSRTM_ATTR_HORZ_REFERENCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSRTM_ATTR_ROLL_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 612
#define RSRTM_ATTR_PROBE_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSRTM_ATTR_PROBE_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSRTM_ATTR_PROBE_INPUT_IMPEDANCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSRTM_ATTR_PROBE_INPUT_CAPACITANCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSRTM_ATTR_PROBE_ATTENUATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSRTM_ATTR_PROBE_BANDWIDTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSRTM_ATTR_PROBE_DC_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 471
#define RSRTM_ATTR_PROBE_ADDITIONAL_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 472
#define RSRTM_ATTR_PROBE_VOLTMETER_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 473
#define RSRTM_ATTR_PROBE_ATTENUATION_UNIT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 645
#define RSRTM_ATTR_PROBE_ATTENUATION_MANUAL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define RSRTM_ATTR_PROBE_MICRO_BUTTON_ACTION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSRTM_ATTR_PROBE_SOFTWARE_VERSION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSRTM_ATTR_PROBE_PRODUCTION_DATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 321
#define RSRTM_ATTR_PROBE_PART_NUMBER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 322
#define RSRTM_ATTR_PROBE_BUILD_NUMBER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 474
#define RSRTM_ATTR_PROBE_SERIAL_NUMBER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 323
#define RSRTM_ATTR_LABEL_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 687
#define RSRTM_ATTR_LABEL_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 688
#define RSRTM_ATTR_CHANNEL_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSRTM_ATTR_VERTICAL_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSRTM_ATTR_VERTICAL_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSRTM_ATTR_VERTICAL_COUPLING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSRTM_ATTR_VERTICAL_SCALE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSRTM_ATTR_CHANNEL_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSRTM_ATTR_CHANNEL_BANDWIDTH_LIMIT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSRTM_ATTR_CHANNEL_POLARITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 615
#define RSRTM_ATTR_CHANNEL_OVERLOAD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSRTM_ATTR_CHANNEL_SKEW                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSRTM_ATTR_CHANNEL_THRESHOLD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSRTM_ATTR_TRIGGER_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSRTM_ATTR_TRIGGER_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSRTM_ATTR_EXTERNAL_TRIGGER_COUPLING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 616
#define RSRTM_ATTR_TRIGGER_HOLDOFF_TIME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 689
#define RSRTM_ATTR_TRIGGER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSRTM_ATTR_TRIGGER_HYSTERESIS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 493
#define RSRTM_ATTR_TRIGGER_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 482
#define RSRTM_ATTR_TRIGGER_MODIFIER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSRTM_ATTR_TRIGGER_EVENT_COUNT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 489
#define RSRTM_ATTR_TRIGGER_LEVEL_AUTO_FIND                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSRTM_ATTR_TRIGGER_DELAY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 488
#define RSRTM_ATTR_TRIGGER_SLOPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSRTM_ATTR_TRIGGER_COUPLING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 490
#define RSRTM_ATTR_TRIGGER_FILTER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 491
#define RSRTM_ATTR_TV_TRIGGER_EVENT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSRTM_ATTR_TV_TRIGGER_LINE_NUMBER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSRTM_ATTR_TV_TRIGGER_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSRTM_ATTR_TV_STANDARD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 477
#define RSRTM_ATTR_WIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define RSRTM_ATTR_WIDTH_DELTA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 480
#define RSRTM_ATTR_WIDTH_POLARITY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 478
#define RSRTM_ATTR_WIDTH_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 479
#define RSRTM_ATTR_TRIGGER_PATTERN_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 494
#define RSRTM_ATTR_TRIGGER_PATTERN_FUNCTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 495
#define RSRTM_ATTR_TRIGGER_PATTERN_POINT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 496
#define RSRTM_ATTR_WAVEFORM_SAMPLES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 500
#define RSRTM_ATTR_RUN_SINGLE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSRTM_ATTR_RUN_CONTINUOUS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSRTM_ATTR_STOP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSRTM_ATTR_SEND_SW_TRIGGER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSRTM_ATTR_WAVEFORM_CONVERSION_X_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 744
#define RSRTM_ATTR_WAVEFORM_CONVERSION_X_INCREMENT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 745
#define RSRTM_ATTR_WAVEFORM_CONVERSION_Y_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 746
#define RSRTM_ATTR_WAVEFORM_CONVERSION_Y_INCREMENT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 747
#define RSRTM_ATTR_WAVEFORM_CONVERSION_Y_RESOLUTION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 748
#define RSRTM_ATTR_ENVELOPE_WAVEFORM_CONVERSION_X_START                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 749
#define RSRTM_ATTR_ENVELOPE_WAVEFORM_CONVERSION_X_INCREMENT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 750
#define RSRTM_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_START                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 751
#define RSRTM_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_INCREMENT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 752
#define RSRTM_ATTR_ENVELOPE_WAVEFORM_CONVERSION_Y_RESOLUTION                RS_SPECIFIC_PUBLIC_ATTR_BASE + 753
#define RSRTM_ATTR_MATH_WAVEFORM_CONVERSION_X_START                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 754
#define RSRTM_ATTR_MATH_WAVEFORM_CONVERSION_X_INCREMENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 755
#define RSRTM_ATTR_MATH_WAVEFORM_CONVERSION_Y_START                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 756
#define RSRTM_ATTR_MATH_WAVEFORM_CONVERSION_Y_INCREMENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 757
#define RSRTM_ATTR_MATH_WAVEFORM_CONVERSION_Y_RESOLUTION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 758
#define RSRTM_ATTR_REFERENCE_WAVEFORM_CONVERSION_X_START                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 759
#define RSRTM_ATTR_REFERENCE_WAVEFORM_CONVERSION_X_INCREMENT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 760
#define RSRTM_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_START                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 761
#define RSRTM_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_INCREMENT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 762
#define RSRTM_ATTR_REFERENCE_WAVEFORM_CONVERSION_Y_RESOLUTION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 763
#define RSRTM_ATTR_MAIN_MEASUREMENT_RESULT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 508
#define RSRTM_ATTR_AMPT_MAIN_MEASUREMENT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSRTM_ATTR_MEAS_DELAY_SLOPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 617
#define RSRTM_ATTR_MEAS_CATEGORY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 618
#define RSRTM_ATTR_MEAS_RELATIVE_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 619
#define RSRTM_ATTR_MEAS_RELATIVE_LOWER_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 620
#define RSRTM_ATTR_MEAS_RELATIVE_UPPER_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 621
#define RSRTM_ATTR_MEAS_RELATIVE_MIDDLE_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 622
#define RSRTM_ATTR_MEASUREMENT_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSRTM_ATTR_MEASUREMENT_CATEGORY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSRTM_ATTR_QUICK_MEASUREMENTS_ENABLE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSRTM_ATTR_QUICK_MEASUREMENTS_DISABLE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSRTM_ATTR_QUICK_MEASUREMENTS_ENABLE_WITH_STATUS_BIT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define RSRTM_ATTR_CLEAR_MEASUREMENT_STATISTIC_DATA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSRTM_ATTR_CURSOR_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSRTM_ATTR_ALL_CURSORS_OFF                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSRTM_ATTR_CURSOR_MEASUREMENT_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSRTM_ATTR_CURSOR_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSRTM_ATTR_CURSOR_TRACKING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSRTM_ATTR_CURSOR_X_POSITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSRTM_ATTR_CURSOR_X_POSITION_COUPLING                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSRTM_ATTR_CURSOR_Y_POSITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSRTM_ATTR_CURSOR_Y_POSITION_COUPLING                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSRTM_ATTR_CURSOR_AUTOSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define RSRTM_ATTR_CURSOR_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define RSRTM_ATTR_CURSOR_PEAK_NEXT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define RSRTM_ATTR_CURSOR_PEAK_PREVIOUS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define RSRTM_ATTR_CURSOR_ADJUSTMENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 507
#define RSRTM_ATTR_CURSOR_X_RATIO_MEASUREMENT_UNIT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSRTM_ATTR_CURSOR_Y_RATIO_MEASUREMENT_UNIT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSRTM_ATTR_CURSOR_X_RATIO_MEASUREMENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSRTM_ATTR_CURSOR_Y_RATIO_MEASUREMENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSRTM_ATTR_CURSOR_DISTANCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSRTM_ATTR_CURSOR_INVERSE_DISTANCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSRTM_ATTR_CURSOR_VOLTAGE_INVERSE_DISTANCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 503
#define RSRTM_ATTR_CURSOR_POSITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 506
#define RSRTM_ATTR_CURSOR_PEAK_EXCURSION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSRTM_ATTR_AUTOMATIC_MEASUREMENT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define RSRTM_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_WAVEFORMS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define RSRTM_ATTR_RESET_AUTOMATIC_MEASUREMENT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define RSRTM_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_MEASURED_WAVEFORMS       RS_SPECIFIC_PUBLIC_ATTR_BASE + 666
#define RSRTM_ATTR_AUTOMATIC_MEASUREMENT_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 654
#define RSRTM_ATTR_AUTOMATIC_MEASUREMENT_RESULT_INDEX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 764
#define RSRTM_ATTR_AUTOMATIC_MEASUREMENT_SINGLE_STATISTICAL_VALUE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 765
#define RSRTM_ATTR_MATH_WAVEFORM_HEADER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSRTM_ATTR_MATH_WAVEFORM_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSRTM_ATTR_MATH_WAVEFORM_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 623
#define RSRTM_ATTR_MATH_VERTICAL_SCALE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 624
#define RSRTM_ATTR_MATH_ACQUISITION_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSRTM_ATTR_MATH_EXPRESSION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSRTM_ATTR_FFT_CENTER_FREQUENCY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSRTM_ATTR_FFT_FREQUENCY_SPAN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSRTM_ATTR_FFT_FULL_SPAN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSRTM_ATTR_FFT_START_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSRTM_ATTR_FFT_STOP_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSRTM_ATTR_FFT_AVERAGING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 509
#define RSRTM_ATTR_FFT_WINDOW_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH_COUPLING_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH_RATIO                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSRTM_ATTR_FFT_EFFECTIVE_RESOLUTION_BANDWIDTH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSRTM_ATTR_FFT_SCALING_UNIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 625
#define RSRTM_ATTR_FFT_SAMPLE_RATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 655
#define RSRTM_ATTR_FFT_YT_WINDOW_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 669
#define RSRTM_ATTR_FFT_YT_WINDOW_WIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 670
#define RSRTM_ATTR_REFERENCE_WAVEFORM_HEADER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 511
#define RSRTM_ATTR_REFERENCE_WAVEFORM_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSRTM_ATTR_REFERENCE_WAVEFORM_UPDATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSRTM_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSRTM_ATTR_REFERENCE_WAVEFORM_LOAD_FROM_FILE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 512
#define RSRTM_ATTR_REFERENCE_WAVEFORM_LOAD_CONFIGURATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 513
#define RSRTM_ATTR_REFERENCE_WAVEFORM_SAVE_TO_FILE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 514
#define RSRTM_ATTR_REFERENCE_WAVEFORM_CATALOG                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 515
#define RSRTM_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSRTM_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSRTM_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_SCALE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 516
#define RSRTM_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_POSITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 611
#define RSRTM_ATTR_MASK_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 517
#define RSRTM_ATTR_MASK_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 525
#define RSRTM_ATTR_MASK_TEST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 526
#define RSRTM_ATTR_MASK_COPY_CHANNEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 518
#define RSRTM_ATTR_MASK_HIT_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 522
#define RSRTM_ATTR_MASK_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 521
#define RSRTM_ATTR_MASK_STORE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 524
#define RSRTM_ATTR_MASK_LOAD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 523
#define RSRTM_ATTR_MASK_TEST_ACTION_EXECUTION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 671
#define RSRTM_ATTR_MASK_TEST_VIOLATION_COUNT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 672
#define RSRTM_ATTR_MASK_RESET_TEST_COUNTER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 673
#define RSRTM_ATTR_MASK_VERTICAL_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 519
#define RSRTM_ATTR_MASK_VERTICAL_SCALING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 520
#define RSRTM_ATTR_MASK_VERTICAL_WIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 528
#define RSRTM_ATTR_MASK_HORIZONTAL_WIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 527
#define RSRTM_ATTR_SEARCH_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 626
#define RSRTM_ATTR_SEARCH_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 627
#define RSRTM_ATTR_SEARCH_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 628
#define RSRTM_ATTR_SEARCH_TRIGGER_EDGE_SLOPE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 629
#define RSRTM_ATTR_SEARCH_TRIGGER_EDGE_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 630
#define RSRTM_ATTR_SEARCH_TRIGGER_EDGE_HYSTERSIS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 631
#define RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 632
#define RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_HYSTERSIS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 633
#define RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_WIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 634
#define RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_DELTA                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 635
#define RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_POLARITY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 636
#define RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_RANGE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 637
#define RSRTM_ATTR_SEARCH_TRIGGER_PEAK_POLARITY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 638
#define RSRTM_ATTR_SEARCH_TRIGGER_PEAK_LIMIT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 639
#define RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_POLARITY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_LEVEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_RANGE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 658
#define RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_REFERENCE_TIME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_DELTA_TIME                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 660
#define RSRTM_ATTR_SEARCH_TRIGGER_RUNT_POLARITY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 661
#define RSRTM_ATTR_SEARCH_TRIGGER_RUNT_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 662
#define RSRTM_ATTR_SEARCH_TRIGGER_RUNT_RANGE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 663
#define RSRTM_ATTR_SEARCH_TRIGGER_RUNT_WIDTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 664
#define RSRTM_ATTR_SEARCH_TRIGGER_RUNT_DELTA_WIDTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 665
#define RSRTM_ATTR_SEARCH_TRIGGER_D2C_CLOCK_SOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 674
#define RSRTM_ATTR_SEARCH_TRIGGER_D2C_LEVEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 675
#define RSRTM_ATTR_SEARCH_TRIGGER_D2C_HYSTERESIS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 676
#define RSRTM_ATTR_SEARCH_TRIGGER_D2C_POLARITY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 677
#define RSRTM_ATTR_SEARCH_TRIGGER_D2C_SETUP_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 678
#define RSRTM_ATTR_SEARCH_TRIGGER_D2C_HOLD_TIME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 679
#define RSRTM_ATTR_SEARCH_TRIGGER_PATTERN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 680
#define RSRTM_ATTR_SEARCH_TRIGGER_PATTERN_COMBINATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 681
#define RSRTM_ATTR_SEARCH_TRIGGER_PATTERN_COMPARISON                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 682
#define RSRTM_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 683
#define RSRTM_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH_DELTA                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 684
#define RSRTM_ATTR_SEARCH_TRIGGER_PATTERN_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 685
#define RSRTM_ATTR_SEARCH_TRIGGER_PATTERN_HYSTERESIS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 686
#define RSRTM_ATTR_SEARCH_GATE_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define RSRTM_ATTR_SEARCH_GATE_START                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 691
#define RSRTM_ATTR_SEARCH_GATE_STOP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 692
#define RSRTM_ATTR_SEARCH_SHOW_RESULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 640
#define RSRTM_ATTR_SEARCH_NUMBER_OF_RESULTS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 641
#define RSRTM_ATTR_PROTOCOL_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 577
#define RSRTM_ATTR_PROTOCOL_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 578
#define RSRTM_ATTR_PROTOCOL_FIND_LEVEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 693
#define RSRTM_ATTR_BUS_SAVE_DECODED_DATA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 695
#define RSRTM_ATTR_PROTOCOL_DISPLAY_FORMAT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 579
#define RSRTM_ATTR_PROTOCOL_DISPLAY_HEIGHT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 580
#define RSRTM_ATTR_PROTOCOL_DISPLAY_LINES                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 581
#define RSRTM_ATTR_PROTOCOL_DISPLAY_VERTICAL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 582
#define RSRTM_ATTR_PROTOCOL_I2C_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350
#define RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ACCESS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 529
#define RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 531
#define RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 530
#define RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 532
#define RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_CONDITION_LENGTH                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 534
#define RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_BIT_PATTERN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 533
#define RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_FIRST_BYTE_OFFSET                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define RSRTM_ATTR_PROTOCOL_I2C_FRAME_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 696
#define RSRTM_ATTR_PROTOCOL_SPI_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 382
#define RSRTM_ATTR_PROTOCOL_SPI_POLARITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 383
#define RSRTM_ATTR_PROTOCOL_SPI_BIT_ORDER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 380
#define RSRTM_ATTR_PROTOCOL_SPI_MISO_POLARITY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 742
#define RSRTM_ATTR_PROTOCOL_SPI_WORD_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define RSRTM_ATTR_PROTOCOL_SPI_TRIGGER_SOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 697
#define RSRTM_ATTR_PROTOCOL_SPI_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define RSRTM_ATTR_PROTOCOL_SPI_TRIGGER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 388
#define RSRTM_ATTR_PROTOCOL_SPI_BIT_PATTERN_LENGTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define RSRTM_ATTR_PROTOCOL_SPI_BIT_PATTERN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 536
#define RSRTM_ATTR_PROTOCOL_SPI_FRAME_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 698
#define RSRTM_ATTR_PROTOCOL_SSPI_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 609
#define RSRTM_ATTR_PROTOCOL_SSPI_POLARITY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 594
#define RSRTM_ATTR_PROTOCOL_SSPI_MISO_POLARITY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 743
#define RSRTM_ATTR_PROTOCOL_SSPI_INTERFRAME_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 597
#define RSRTM_ATTR_PROTOCOL_SSPI_BIT_ORDER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 598
#define RSRTM_ATTR_PROTOCOL_SSPI_WORD_LENGTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 599
#define RSRTM_ATTR_PROTOCOL_UART_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 600
#define RSRTM_ATTR_PROTOCOL_UART_SOURCE_LINE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 699
#define RSRTM_ATTR_PROTOCOL_UART_POLARITY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 601
#define RSRTM_ATTR_PROTOCOL_UART_INTERFRAME_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 605
#define RSRTM_ATTR_PROTOCOL_UART_WORD_LENGTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 606
#define RSRTM_ATTR_PROTOCOL_UART_BIT_RATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 604
#define RSRTM_ATTR_PROTOCOL_UART_PARITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSRTM_ATTR_PROTOCOL_UART_STOP_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 603
#define RSRTM_ATTR_PROTOCOL_UART_TRIGGER_SOURCE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 700
#define RSRTM_ATTR_PROTOCOL_UART_TRIGGER_MODE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define RSRTM_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 541
#define RSRTM_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION_INDEX_MIN            RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define RSRTM_ATTR_PROTOCOL_UART_TRIGGER_CONDITION_LENGTH                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 543
#define RSRTM_ATTR_PROTOCOL_UART_FRAME_COUNT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 701
#define RSRTM_ATTR_PROTOCOL_LIN_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 702
#define RSRTM_ATTR_PROTOCOL_LIN_POLARITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 741
#define RSRTM_ATTR_PROTOCOL_LIN_STANDARD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 703
#define RSRTM_ATTR_PROTOCOL_LIN_BIT_RATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 704
#define RSRTM_ATTR_PROTOCOL_LIN_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 705
#define RSRTM_ATTR_PROTOCOL_LIN_TRIGGER_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 706
#define RSRTM_ATTR_PROTOCOL_LIN_TRIGGER_ID_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 707
#define RSRTM_ATTR_PROTOCOL_LIN_TRIGGER_DATA_LENGTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 708
#define RSRTM_ATTR_PROTOCOL_LIN_TRIGGER_DATA_PATTERN                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 709
#define RSRTM_ATTR_PROTOCOL_LIN_TRIGGER_ERROR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 710
#define RSRTM_ATTR_PROTOCOL_LIN_FRAME_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 711
#define RSRTM_ATTR_PROTOCOL_LIN_SEARCH_EVENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 712
#define RSRTM_ATTR_PROTOCOL_LIN_SEARCH_FRAME_SETUP                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 713
#define RSRTM_ATTR_PROTOCOL_LIN_SEARCH_CONDITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 714
#define RSRTM_ATTR_PROTOCOL_LIN_SEARCH_ID_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 715
#define RSRTM_ATTR_PROTOCOL_LIN_SEARCH_DATA_LENGTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 716
#define RSRTM_ATTR_PROTOCOL_LIN_SEARCH_DATA_PATTERN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 717
#define RSRTM_ATTR_PROTOCOL_LIN_SEARCH_ERROR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 718
#define RSRTM_ATTR_PROTOCOL_CAN_LINE_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 719
#define RSRTM_ATTR_PROTOCOL_CAN_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 720
#define RSRTM_ATTR_PROTOCOL_CAN_BIT_RATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 721
#define RSRTM_ATTR_PROTOCOL_CAN_SAMPLE_POINT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 722
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 723
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 724
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 725
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_ID_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 726
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_ID_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 727
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_DATA_LENGTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 728
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_DATA_PATTERN                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 729
#define RSRTM_ATTR_PROTOCOL_CAN_TRIGGER_ERROR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 730
#define RSRTM_ATTR_PROTOCOL_CAN_FRAME_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 731
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_EVENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 732
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_FRAME_SETUP                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 733
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_FRAME_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 734
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_ID_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 735
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_CONDITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 736
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_ID_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 737
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_DATA_LENGTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 738
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_DATA_PATTERN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 739
#define RSRTM_ATTR_PROTOCOL_CAN_SEARCH_ERROR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 740
#define RSRTM_ATTR_PARALLEL_BUS_ANALYZED_LINES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 608
#define RSRTM_ATTR_DISPLAY_STYLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 574
#define RSRTM_ATTR_COLOR_AND_BRIGHTNESS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 547
#define RSRTM_ATTR_SIGNAL_STYLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 427
#define RSRTM_ATTR_DIAGRAM_GRID_STYLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 550
#define RSRTM_ATTR_WAVEFORM_INTENSITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 573
#define RSRTM_ATTR_BACKGROUND_INTENSITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 545
#define RSRTM_ATTR_GRID_INTENSITY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 546
#define RSRTM_ATTR_DISPLAY_LANGUAGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 549
#define RSRTM_ATTR_REMOVE_DISPLAY_LANGUAGE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 766
#define RSRTM_ATTR_DIAGRAM_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 548
#define RSRTM_ATTR_PERSISTENCE_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 422
#define RSRTM_ATTR_INFINITE_PERSISTENCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 423
#define RSRTM_ATTR_PERSISTENCE_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 424
#define RSRTM_ATTR_PERSISTENCE_TIME_AUTO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 544
#define RSRTM_ATTR_PERSISTENCE_CLEAR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 572
#define RSRTM_ATTR_XY_X_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 551
#define RSRTM_ATTR_XY_Y_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 552
#define RSRTM_ATTR_XY_Y2_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 554
#define RSRTM_ATTR_XY_Z_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 553
#define RSRTM_ATTR_XY_Z_TRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define RSRTM_ATTR_XY_INTENSITY_CONTROL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 555
#define RSRTM_ATTR_ZOOM_WINDOW_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 557
#define RSRTM_ATTR_ZOOM_DIAGRAM_TIMEBASE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 558
#define RSRTM_ATTR_ZOOM_OFFSET_OF_TRIGGER_POINT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 559
#define RSRTM_ATTR_ZOOM_REFERENCE_POINT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 560
#define RSRTM_ATTR_MARKER_SET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 561
#define RSRTM_ATTR_MARKER_CLEAR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define RSRTM_ATTR_MARKER_CLEAR_ALL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 563
#define RSRTM_ATTR_MARKER_NEXT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 564
#define RSRTM_ATTR_MARKER_PREVIOUS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 565
#define RSRTM_ATTR_DRIVES                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define RSRTM_ATTR_CHANGE_DRIVE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define RSRTM_ATTR_CURRENT_DIRECTORY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSRTM_ATTR_CREATE_DIRECTORY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSRTM_ATTR_REMOVE_DIRECTORY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSRTM_ATTR_DELETE_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSRTM_ATTR_HARDCOPY_FILE_NAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSRTM_ATTR_HARDCOPY_LANGUAGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 575
#define RSRTM_ATTR_HARDCOPY_DEVICE_DESTINATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 455
#define RSRTM_ATTR_HARDCOPY_COLOR_SCHEME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define RSRTM_ATTR_HARDCOPY_DEVICE_LANGUAGE_OUTPUT_FORMAT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSRTM_ATTR_HARDCOPY_DEVICE_ORIENTATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define RSRTM_ATTR_HARDCOPY_PAGE_SIZE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 567
#define RSRTM_ATTR_HARDCOPY_PRINT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 458
#define RSRTM_ATTR_HARDCOPY_SELECT_PRINTER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 459
#define RSRTM_ATTR_HARDCOPY_GET_FIRST_PRINTER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 460
#define RSRTM_ATTR_HARDCOPY_GET_NEXT_PRINTER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define RSRTM_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSRTM_ATTR_CALIBRATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSRTM_ATTR_SELF_TEST_QUERY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSRTM_ATTR_SYSTEM_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define RSRTM_ATTR_SYST_ERR_LIST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define RSRTM_ATTR_INSTRUMENT_NAME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 568
#define RSRTM_ATTR_RESET_STATUS_REGISTER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define RSRTM_ATTR_REGISTER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 570

// rsrtm_rngSampleMode
#define RSRTM_VAL_REAL_TIME                                                 0
#define RSRTM_VAL_EQUIVALENT_TIME                                           1

// rsrtm_rngWaveformArithmetics
#define RSRTM_VAL_OFF                                                       0
#define RSRTM_VAL_ENVELOPE                                                  1
#define RSRTM_VAL_AVERAGE                                                   2
#define RSRTM_VAL_SMOOTH                                                    3
#define RSRTM_VAL_FILTER                                                    4

// rsrtm_rngVerticalCoupling
#define RSRTM_VAL_AC                                                        0
#define RSRTM_VAL_DC                                                        1
#define RSRTM_VAL_DC_LIMIT                                                  2

// rsrtm_rngChannelBWLimit
#define RSRTM_VAL_BW_FULL                                                   0
#define RSRTM_VAL_BW_400                                                    1
#define RSRTM_VAL_BW_200                                                    2
#define RSRTM_VAL_BW_20                                                     3

// rsrtm_rngTriggerSource
#define RSRTM_VAL_CHANNEL1                                                  1
#define RSRTM_VAL_CHANNEL2                                                  2
#define RSRTM_VAL_CHANNEL3                                                  3
#define RSRTM_VAL_CHANNEL4                                                  4
#define RSRTM_VAL_EXTERNAL                                                  5
#define RSRTM_VAL_LINE                                                      6
#define RSRTM_VAL_SBUS                                                      7

// rsrtm_rngTriggerSlope
#define RSRTM_VAL_POSITIVE                                                  0
#define RSRTM_VAL_NEGATIVE                                                  1
#define RSRTM_VAL_EITHER                                                    2

// rsrtm_rngWidthCondition
#define RSRTM_VAL_SHORTER                                                   0
#define RSRTM_VAL_LONGER                                                    1
#define RSRTM_VAL_WITHIN                                                    2
#define RSRTM_VAL_OUTSIDE                                                   3

// rsrtm_rngTVTriggerEvent
#define RSRTM_VAL_TV_EVENT_EVEN                                             0
#define RSRTM_VAL_TV_EVENT_ODD                                              1
#define RSRTM_VAL_TV_EVENT_ANY_FIELD                                        2
#define RSRTM_VAL_TV_EVENT_LINE                                             3
#define RSRTM_VAL_TV_EVENT_ANY_LINE                                         4

// rsrtm_rngChannelPatternCombination
#define RSRTM_VAL_AND                                                       0
#define RSRTM_VAL_OR                                                        1

// rsrtm_rngFalseTrue
#define RSRTM_VAL_FALSE                                                     0
#define RSRTM_VAL_TRUE                                                      1

// rsrtm_rngCursorFunction
#define RSRTM_VAL_CURSOR_HORIZONTAL                                         0
#define RSRTM_VAL_CURSOR_VERTICAL                                           1
#define RSRTM_VAL_CURSOR_PAIRED                                             2
#define RSRTM_VAL_CURSOR_HRAT                                               3
#define RSRTM_VAL_CURSOR_VRAT                                               4
#define RSRTM_VAL_CURSOR_PPC                                                5
#define RSRTM_VAL_CURSOR_NPC                                                6
#define RSRTM_VAL_CURSOR_REC                                                7
#define RSRTM_VAL_CURSOR_FEC                                                8
#define RSRTM_VAL_CURSOR_MEAN                                               9
#define RSRTM_VAL_CURSOR_RMS                                                10
#define RSRTM_VAL_CURSOR_RTIM                                               11
#define RSRTM_VAL_CURSOR_FTIM                                               12
#define RSRTM_VAL_CURSOR_PEAK                                               13
#define RSRTM_VAL_CURSOR_UPE                                                14
#define RSRTM_VAL_CURSOR_LPE                                                15
#define RSRTM_VAL_CURSOR_BWIDTH                                             16

// rsrtm_rngXRatioMeasurementUnit
#define RSRTM_VAL_UNIT_RATIO                                                0
#define RSRTM_VAL_UNIT_PCT                                                  1
#define RSRTM_VAL_UNIT_DEGREE                                               2
#define RSRTM_VAL_UNIT_RAD                                                  3

// rsrtm_rngRollModeAuto
#define RSRTM_VAL_AUTO                                                      1

// rsrtm_rngInterpolation
#define RSRTM_VAL_SINE_X                                                    0
#define RSRTM_VAL_LINEAR                                                    1
#define RSRTM_VAL_SAMPLE_HOLD                                               2

// rsrtm_rngMeasurementCategory
#define RSRTM_VAL_AMPTIME                                                   0

// rsrtm_rngFFTWindowType
#define RSRTM_VAL_RECTANGULAR                                               0
#define RSRTM_VAL_HAMMING                                                   1
#define RSRTM_VAL_HANN                                                      2
#define RSRTM_VAL_BLACKMAN                                                  3

// rsrtm_rngProtocolI2CFrameState
#define RSRTM_VAL_FRAME_STATE_OK                                            0
#define RSRTM_VAL_FRAME_STATE_INCOMPLETE                                    1
#define RSRTM_VAL_FRAME_STATE_UNEXPSTOP                                     2
#define RSRTM_VAL_FRAME_STATE_INSUFFICIENT                                  3
#define RSRTM_VAL_FRAME_STATE_ADDIFFERENT                                   4

// rsrtm_rngProtocolAckBit
#define RSRTM_VAL_I2C_EITHER                                                0
#define RSRTM_VAL_I2C_ACK                                                   1
#define RSRTM_VAL_I2C_NACK                                                  2
#define RSRTM_VAL_I2C_INCOMPLETE                                            3

// rsrtm_rngProtocolSPIBitOrder
#define RSRTM_VAL_SPI_MSBF                                                  0
#define RSRTM_VAL_SPI_LSBF                                                  1

// rsrtm_rngProtocolWaveformSource
#define RSRTM_VAL_PROTOCOL_WAV_NONE                                         0
#define RSRTM_VAL_PROTOCOL_WAV_C1W1                                         1
#define RSRTM_VAL_PROTOCOL_WAV_C2W1                                         2
#define RSRTM_VAL_PROTOCOL_WAV_C3W1                                         3
#define RSRTM_VAL_PROTOCOL_WAV_C4W1                                         4
#define RSRTM_VAL_PROTOCOL_WAV_M1                                           5
#define RSRTM_VAL_PROTOCOL_WAV_M2                                           6
#define RSRTM_VAL_PROTOCOL_WAV_M3                                           7
#define RSRTM_VAL_PROTOCOL_WAV_M4                                           8
#define RSRTM_VAL_PROTOCOL_WAV_R1                                           9
#define RSRTM_VAL_PROTOCOL_WAV_R2                                           10
#define RSRTM_VAL_PROTOCOL_WAV_R3                                           11
#define RSRTM_VAL_PROTOCOL_WAV_R4                                           12

// rsrtm_rngProtocolSPIPolarity
#define RSRTM_VAL_ACTLOW                                                    0
#define RSRTM_VAL_ACTHIGH                                                   1

// rsrtm_rngProtocolSPIDataAlignment
#define RSRTM_VAL_SPI_TRIGGER_BIT                                           0
#define RSRTM_VAL_SPI_TRIGGER_WORD                                          1

// rsrtm_rngProtocolSPIFrameState
#define RSRTM_VAL_FRAME_STATE_INCFIRST                                      1
#define RSRTM_VAL_FRAME_STATE_INCLAST                                       2

// rsrtm_rngProtocolUARTParity
#define RSRTM_VAL_UART_NONE                                                 0
#define RSRTM_VAL_UART_ODD                                                  1
#define RSRTM_VAL_UART_EVEN                                                 2

// rsrtm_rngProtocolUARTStopBits
#define RSRTM_VAL_UART_B1                                                   0
#define RSRTM_VAL_UART_B1_5                                                 1
#define RSRTM_VAL_UART_B2                                                   2

// rsrtm_rngProtocolUARTTriggerType
#define RSRTM_VAL_UART_TRIGGER_BURSTSTART                                   0
#define RSRTM_VAL_UART_TRIGGER_SBIT                                         1
#define RSRTM_VAL_UART_TRIGGER_NTHS                                         2
#define RSRTM_VAL_UART_TRIGGER_SYMB                                         3
#define RSRTM_VAL_UART_TRIGGER_PATT                                         4
#define RSRTM_VAL_UART_TRIGGER_PERR                                         5
#define RSRTM_VAL_UART_TRIGGER_FERR                                         6
#define RSRTM_VAL_UART_TRIGGER_BRE                                          7

// rsrtm_rngSignalStyle
#define RSRTM_VAL_SIGNAL_STYLE_VECTORS                                      0
#define RSRTM_VAL_SIGNAL_STYLE_DOTS                                         1

// rsrtm_rngHardcopyDeviceOrientation
#define RSRTM_VAL_HARDCOPY_ORIENTATION_PORTRAIT                             0
#define RSRTM_VAL_HARDCOPY_ORIENTATION_LANDSCAPE                            1

// rsrtm_rngWaveformParameter
#define RSRTM_VAL_WAV_CH1                                                   1
#define RSRTM_VAL_WAV_CH2                                                   2
#define RSRTM_VAL_WAV_CH3                                                   3
#define RSRTM_VAL_WAV_CH4                                                   4
#define RSRTM_VAL_WAV_M1                                                    5
#define RSRTM_VAL_WAV_M2                                                    6
#define RSRTM_VAL_WAV_M3                                                    7
#define RSRTM_VAL_WAV_M4                                                    8
#define RSRTM_VAL_WAV_M5                                                    9
#define RSRTM_VAL_WAV_R1                                                    10
#define RSRTM_VAL_WAV_R2                                                    11
#define RSRTM_VAL_WAV_R3                                                    12
#define RSRTM_VAL_WAV_R4                                                    13

// rsrtm_rngProtocolI2CAddressAccessBit
#define RSRTM_VAL_I2C_ACCESS_EITHER                                         0
#define RSRTM_VAL_I2C_ACCESS_ACK                                            1
#define RSRTM_VAL_I2C_ACCESS_NACK                                           2
#define RSRTM_VAL_I2C_ACCESS_INCOMPLETE                                     3

// rsrtm_rngSampleRate
#define RSRTM_VAL_RATE_AUTO                                                 0
#define RSRTM_VAL_RATE_MAX_SAM                                              2
#define RSRTM_VAL_RATE_MAX_WAV                                              1

// rsrtm_rngColorBrightness
#define RSRTM_VAL_COLOR_NORM                                                0
#define RSRTM_VAL_COLOR_INVERSE                                             1
#define RSRTM_VAL_COLOR_FCOLOR                                              2
#define RSRTM_VAL_COLOR_INVCOLOR                                            3

// rsrtm_rngDiagramMode
#define RSRTM_VAL_DISPLAY_YT                                                0
#define RSRTM_VAL_DISPLAY_XY                                                1

// rsrtm_rngLanguage
#define RSRTM_VAL_DISPLAY_ENGLISH                                           0
#define RSRTM_VAL_DISPLAY_GERMAN                                            1
#define RSRTM_VAL_DISPLAY_FRENCH                                            2
#define RSRTM_VAL_DISPLAY_SPANISH                                           3
#define RSRTM_VAL_DISPLAY_RUSSIAN                                           4
#define RSRTM_VAL_DISPLAY_SCHIN                                             5
#define RSRTM_VAL_DISPLAY_TCHIN                                             6
#define RSRTM_VAL_DISPLAY_JAPAN                                             7
#define RSRTM_VAL_DISPLAY_KOREAN                                            8

// rsrtm_rngGridStyle
#define RSRTM_VAL_GRID_LINES                                                0
#define RSRTM_VAL_GRID_CROSS                                                1
#define RSRTM_VAL_GRID_NONE                                                 2

// rsrtm_rngSource
#define RSRTM_VAL_SOURCE_CH1                                                1
#define RSRTM_VAL_SOURCE_CH2                                                2
#define RSRTM_VAL_SOURCE_CH3                                                3
#define RSRTM_VAL_SOURCE_CH4                                                4
#define RSRTM_VAL_SOURCE_NONE                                               0

// rsrtm_rngIntensityMode
#define RSRTM_VAL_ZMODE_ANALOG                                              0
#define RSRTM_VAL_ZMODE_DIGITAL                                             1
#define RSRTM_VAL_ZMODE_OFF                                                 2

// rsrtm_rngHardcopyDevice
#define RSRTM_VAL_HARDCOPY_DEVICE_MEM                                       0
#define RSRTM_VAL_HARDCOPY_DEVICE_PRINT                                     1

// rsrtm_rngHardcopyDeviceLang
#define RSRTM_VAL_HARDCOPY_DEVICE_LANG_BMP                                  1
#define RSRTM_VAL_HARDCOPY_DEVICE_LANG_PNG                                  0

// rsrtm_rngPageSize
#define RSRTM_VAL_PAGE_A4                                                   0
#define RSRTM_VAL_PAGE_A5                                                   1
#define RSRTM_VAL_PAGE_B5                                                   2
#define RSRTM_VAL_PAGE_B6                                                   3
#define RSRTM_VAL_PAGE_EX                                                   4

// rsrtm_rngMeasResultRTM
#define RSRTM_VAL_MEAS_RES_FREQ                                             0
#define RSRTM_VAL_MEAS_RES_PERIOD                                           1
#define RSRTM_VAL_MEAS_RES_PEAK                                             2
#define RSRTM_VAL_MEAS_RES_UPEAK                                            3
#define RSRTM_VAL_MEAS_RES_LPEAK                                            4
#define RSRTM_VAL_MEAS_RES_PPC                                              5
#define RSRTM_VAL_MEAS_RES_NPC                                              6
#define RSRTM_VAL_MEAS_RES_REC                                              7
#define RSRTM_VAL_MEAS_RES_HIGH                                             8
#define RSRTM_VAL_MEAS_RES_LOW                                              9
#define RSRTM_VAL_MEAS_RES_AMP                                              10
#define RSRTM_VAL_MEAS_RES_MEAN                                             11
#define RSRTM_VAL_MEAS_RES_RMS                                              12
#define RSRTM_VAL_MEAS_RES_RTM                                              13
#define RSRTM_VAL_MEAS_RES_FTIM                                             14
#define RSRTM_VAL_MEAS_RES_PDCY                                             15
#define RSRTM_VAL_MEAS_RES_NDCY                                             16
#define RSRTM_VAL_MEAS_RES_PPW                                              17
#define RSRTM_VAL_MEAS_RES_NPW                                              18
#define RSRTM_VAL_MEAS_RES_CYCM                                             19
#define RSRTM_VAL_MEAS_RES_CYCR                                             20
#define RSRTM_VAL_MEAS_RES_SSTDD                                            21
#define RSRTM_VAL_MEAS_RES_TFR                                              22
#define RSRTM_VAL_MEAS_RES_TPER                                             23

// rsrtm_rngChannelRTM
#define RSRTM_VAL_CHANNELRTM_1                                              1
#define RSRTM_VAL_CHANNELRTM_2                                              2
#define RSRTM_VAL_CHANNELRTM_3                                              3
#define RSRTM_VAL_CHANNELRTM_4                                              4

// rsrtm_rngMaskCondition
#define RSRTM_VAL_MASKCOND_RUN                                              0
#define RSRTM_VAL_MASKCOND_STOP                                             1
#define RSRTM_VAL_MASKCOND_PAUSE                                            2

// rsrtm_rngProbeButtonAction
#define RSRTM_VAL_PROBE_BUTTON_NO_ACTION                                    0
#define RSRTM_VAL_PROBE_BUTTON_RUN_CONTINUOUS                               1
#define RSRTM_VAL_PROBE_BUTTON_RUN_SINGLE                                   2
#define RSRTM_VAL_PROBE_BUTTON_AUTOSET                                      3

// rsrtm_rngTriggerCoupling
#define RSRTM_VAL_COUPLING_DIRECT                                           0
#define RSRTM_VAL_COUPLING_ALTERNATING                                      1
#define RSRTM_VAL_COUPLING_HIGHFREQ                                         2

// rsrtm_rngProtocolI2CAccessBit
#define RSRTM_VAL_I2C_TRIGGER_READ                                          1
#define RSRTM_VAL_I2C_TRIGGER_WRITE                                         2

// rsrtm_rngAddressLength
#define RSRTM_VAL_LENGTH_NORMAL                                             0
#define RSRTM_VAL_LENGTH_EXTENDED                                           1

// rsrtm_rngProtocolI2CTriggerType
#define RSRTM_VAL_TRIGGER_MODE_START                                        0
#define RSRTM_VAL_TRIGGER_MODE_RESTART                                      1
#define RSRTM_VAL_TRIGGER_MODE_STOP                                         2
#define RSRTM_VAL_TRIGGER_MODE_MISSING                                      3
#define RSRTM_VAL_TRIGGER_MODE_PATT                                         4

// rsrtm_rngHysteresisMode
#define RSRTM_VAL_HYSTERESIS_AUTO                                           0
#define RSRTM_VAL_HYSTERESIS_SMALL                                          1
#define RSRTM_VAL_HYSTERESIS_MEDIUM                                         2
#define RSRTM_VAL_HYSTERESIS_LARGE                                          3

// rsrtm_rngTriggerMode
#define RSRTM_VAL_TRIGGER_AUTO                                              0
#define RSRTM_VAL_TRIGGER_NORMAL                                            1
#define RSRTM_VAL_TRIGGER_DELAY                                             2
#define RSRTM_VAL_TRIGGER_EVENTS                                            3

// rsrtm_rngTriggerPatternFunction
#define RSRTM_VAL_TRG_PATTERN_AND                                           0
#define RSRTM_VAL_TRG_PATTERN_OR                                            1

// rsrtm_rngProtocolSPITriggerType
#define RSRTM_VAL_SPI_MODE_BURSTSTART                                       0
#define RSRTM_VAL_SPI_MODE_BURSTEND                                         1
#define RSRTM_VAL_SPI_MODE_BIT                                              2
#define RSRTM_VAL_SPI_MODE_PATTERN                                          3

// rsrtm_rngTriggerType
#define RSRTM_VAL_EDGE_TRIGGER                                              0
#define RSRTM_VAL_WIDTH_TRIGGER                                             1
#define RSRTM_VAL_VIDEO_TRIGGER                                             2
#define RSRTM_VAL_PATTERN_TRIGGER                                           3
#define RSRTM_VAL_BUS_TRIGGER                                               4

// rsrtm_rngTVStandard
#define RSRTM_VAL_TV_STANDART_PAL                                           0
#define RSRTM_VAL_TV_STANDART_NTSC                                          1
#define RSRTM_VAL_TV_STANDART_SECAM                                         2
#define RSRTM_VAL_TV_STANDART_PALM                                          3
#define RSRTM_VAL_TV_STANDART_I576                                          4
#define RSRTM_VAL_TV_STANDART_P720                                          5
#define RSRTM_VAL_TV_STANDART_P1080                                         6
#define RSRTM_VAL_TV_STANDART_I1080                                         7

// rsrtm_rngProtocolUARTTriggerMode
#define RSRTM_VAL_UART_MODE_RTM_BURSTSTART                                  0
#define RSRTM_VAL_UART_MODE_RTM_SBIT                                        1
#define RSRTM_VAL_UART_MODE_RTM_NTHS                                        2
#define RSRTM_VAL_UART_MODE_RTM_SYMB                                        3
#define RSRTM_VAL_UART_MODE_RTM_PATT                                        4
#define RSRTM_VAL_UART_MODE_RTM_PERR                                        5
#define RSRTM_VAL_UART_MODE_RTM_FERR                                        6
#define RSRTM_VAL_UART_MODE_RTM_BRE                                         7

// rsrtm_rngColorScheme
#define RSRTM_VAL_SCHEME_COLOR                                              0
#define RSRTM_VAL_SCHEME_GRAY                                               1
#define RSRTM_VAL_SCHEME_INVERTED                                           2

// rsrtm_rngAcquisitionType
#define RSRTM_VAL_SAMPLE                                                    0
#define RSRTM_VAL_PEAK_DETECT                                               1
#define RSRTM_VAL_HI_RES                                                    2

// rsrtm_rngAmplitudeTimeMeasurementType
#define RSRTM_VAL_MEAS_FREQUENCY                                            1
#define RSRTM_VAL_MEAS_PERIOD                                               2
#define RSRTM_VAL_MEAS_PEAK                                                 3
#define RSRTM_VAL_MEAS_UPEAK                                                4
#define RSRTM_VAL_MEAS_LPEAK                                                5
#define RSRTM_VAL_MEAS_PPC                                                  6
#define RSRTM_VAL_MEAS_NPC                                                  7
#define RSRTM_VAL_MEAS_REC                                                  8
#define RSRTM_VAL_MEAS_FEC                                                  9
#define RSRTM_VAL_MEAS_HIGH                                                 10
#define RSRTM_VAL_MEAS_LOW                                                  11
#define RSRTM_VAL_MEAS_AMP                                                  12
#define RSRTM_VAL_MEAS_MEAN                                                 13
#define RSRTM_VAL_MEAS_RMS                                                  14
#define RSRTM_VAL_MEAS_RTM                                                  15
#define RSRTM_VAL_MEAS_FTIM                                                 16
#define RSRTM_VAL_MEAS_PDCY                                                 17
#define RSRTM_VAL_MEAS_NDCY                                                 18
#define RSRTM_VAL_MEAS_PPW                                                  19
#define RSRTM_VAL_MEAS_NPW                                                  20
#define RSRTM_VAL_MEAS_CYCM                                                 21
#define RSRTM_VAL_MEAS_CYCR                                                 22
#define RSRTM_VAL_MEAS_SSTDD                                                23
#define RSRTM_VAL_MEAS_TFR                                                  24
#define RSRTM_VAL_MEAS_TPER                                                 25
#define RSRTM_VAL_MEAS_DEL                                                  26
#define RSRTM_VAL_MEAS_PHA                                                  27
#define RSRTM_VAL_MEAS_BWID                                                 28
#define RSRTM_VAL_MEAS_CYCS                                                 29
#define RSRTM_VAL_MEAS_POV                                                  30
#define RSRTM_VAL_MEAS_NOV                                                  31
#define RSRTM_VAL_MEAS_TBFR                                                 32
#define RSRTM_VAL_MEAS_TBP                                                  33

// rsrtm_rngHardcopyLang
#define RSRTM_VAL_HARDCOPY_LANG_GDI                                         0
#define RSRTM_VAL_HARDCOPY_LANG_BMP                                         1
#define RSRTM_VAL_HARDCOPY_LANG_PNG                                         2

// rsrtm_rngProtocolType
#define RSRTM_VAL_PTYPE_RTM_PARALLEL                                        0
#define RSRTM_VAL_PTYPE_RTM_CPARALLEL                                       1
#define RSRTM_VAL_PTYPE_RTM_I2C                                             2
#define RSRTM_VAL_PTYPE_RTM_SPI                                             3
#define RSRTM_VAL_PTYPE_RTM_SSPI                                            4
#define RSRTM_VAL_PTYPE_RTM_UART                                            5
#define RSRTM_VAL_PTYPE_RTM_CAN                                             6
#define RSRTM_VAL_PTYPE_RTM_LIN                                             7

// rsrtm_rngProtocolFormat
#define RSRTM_VAL_PFORMAT_ASCI                                              0
#define RSRTM_VAL_PFORMAT_HEX                                               1
#define RSRTM_VAL_PFORMAT_BIN                                               2
#define RSRTM_VAL_PFORMAT_DEC                                               3

// rsrtm_rngProtocolHeight
#define RSRTM_VAL_PHEIGHT_SMALL                                             0
#define RSRTM_VAL_PHEIGHT_MEDIUM                                            1
#define RSRTM_VAL_PHEIGHT_LARGE                                             2

// rsrtm_rngRelativeMode
#define RSRTM_VAL_MEAS_RELATIVE_TEN                                         0
#define RSRTM_VAL_MEAS_RELATIVE_TWENTY                                      1
#define RSRTM_VAL_MEAS_RELATIVE_FIVE                                        2
#define RSRTM_VAL_MEAS_RELATIVE_USER                                        3

// rsrtm_rngChannelPolarity
#define RSRTM_VAL_POLARITY_NORM                                             0
#define RSRTM_VAL_POLARITY_INV                                              1

// rsrtm_rngExternalTriggerCoupling
#define RSRTM_VAL_COUPLING_AC                                               0
#define RSRTM_VAL_COUPLING_DC                                               1

// rsrtm_rngMeasCategory
#define RSRTM_VAL_MEAS_AMPT                                                 0

// rsrtm_rngSearchCondition
#define RSRTM_VAL_SEARCHCOND_EDGE                                           0
#define RSRTM_VAL_SEARCHCOND_WIDTH                                          1
#define RSRTM_VAL_SEARCHCOND_PEAK                                           2
#define RSRTM_VAL_SEARCHCOND_RUNT                                           3
#define RSRTM_VAL_SEARCHCOND_RTIME                                          4
#define RSRTM_VAL_SEARCHCOND_D2C                                            5
#define RSRTM_VAL_SEARCHCOND_PATTERN                                        6
#define RSRTM_VAL_SEARCHCOND_PROTOCOL                                       7

// rsrtm_rngSearchSource
#define RSRTM_VAL_MEASUREMENT_SOURCE_C1                                     0
#define RSRTM_VAL_MEASUREMENT_SOURCE_C2                                     1
#define RSRTM_VAL_MEASUREMENT_SOURCE_C3                                     2
#define RSRTM_VAL_MEASUREMENT_SOURCE_C4                                     3
#define RSRTM_VAL_MEASUREMENT_SOURCE_MA1                                    4
#define RSRTM_VAL_MEASUREMENT_SOURCE_MA2                                    5
#define RSRTM_VAL_MEASUREMENT_SOURCE_MA3                                    6
#define RSRTM_VAL_MEASUREMENT_SOURCE_MA4                                    7
#define RSRTM_VAL_MEASUREMENT_SOURCE_RE1                                    8
#define RSRTM_VAL_MEASUREMENT_SOURCE_RE2                                    9
#define RSRTM_VAL_MEASUREMENT_SOURCE_RE3                                    10
#define RSRTM_VAL_MEASUREMENT_SOURCE_RE4                                    11

// rsrtm_rngScalingUnit
#define RSRTM_VAL_FFT_LIN                                                   0
#define RSRTM_VAL_FFT_DBM                                                   1
#define RSRTM_VAL_FFT_DBV                                                   2

// rsrtm_rngProbeUnit
#define RSRTM_VAL_PROBE_UNIT_V                                              0
#define RSRTM_VAL_PROBE_UNIT_A                                              1

// rsrtm_rngWaveformSamplesRange
#define RSRTM_VAL_WAVEFORM_SAMPLES_DEFAULT                                  0
#define RSRTM_VAL_WAVEFORM_SAMPLES_MAXIMUM                                  1
#define RSRTM_VAL_WAVEFORM_SAMPLES_DISPLAY_MAXIMUM                          2

// rsrtm_rngMaskTestActionExecution
#define RSRTM_VAL_MASK_ACTION_EXECUTION_OFF                                 0
#define RSRTM_VAL_MASK_ACTION_EXECUTION_EACH                                1
#define RSRTM_VAL_MASK_ACTION_EXECUTION_SINGLE                              2
#define RSRTM_VAL_MASK_ACTION_EXECUTION_CYCLIC                              3

// rsrtm_rngSearchTriggerPatternCombination
#define RSRTM_VAL_PATTERN_COMBINATION_AND                                   0
#define RSRTM_VAL_PATTERN_COMBINATION_OR                                    1
#define RSRTM_VAL_PATTERN_COMBINATION_NAND                                  2
#define RSRTM_VAL_PATTERN_COMBINATION_NOR                                   3

// rsrtm_rngSearchGateMode
#define RSRTM_VAL_SEARCH_GATE_ALL                                           0
#define RSRTM_VAL_SEARCH_GATE_DISPLAY                                       1
#define RSRTM_VAL_SEARCH_GATE_USER                                          2

// rsrtm_rngProtocolSPITriggerSource
#define RSRTM_VAL_SPI_MISO                                                  3
#define RSRTM_VAL_SPI_MOSI                                                  4

// rsrtm_rngProtocolUARTTriggerSource
#define RSRTM_VAL_UART_RX                                                   0
#define RSRTM_VAL_UART_TX                                                   1

// rsrtm_rngProtocolLINStandard
#define RSRTM_VAL_LIN_STANDARD_AUTO                                         0
#define RSRTM_VAL_LIN_STANDARD_1X                                           1
#define RSRTM_VAL_LIN_STANDARD_2X                                           2
#define RSRTM_VAL_LIN_STANDARD_J2602                                        3

// rsrtm_rngProtocolLINTriggerMode
#define RSRTM_VAL_LIN_FRAME_START                                           0
#define RSRTM_VAL_LIN_FRAME_ID                                              1
#define RSRTM_VAL_LIN_FRAME_ID_DATA                                         2
#define RSRTM_VAL_LIN_FRAME_WAKEUP                                          3
#define RSRTM_VAL_LIN_ERR_COND                                              4

// rsrtm_rngProtocolCondition
#define RSRTM_VAL_COND_NQ                                                   0
#define RSRTM_VAL_COND_EQ                                                   1
#define RSRTM_VAL_COND_LT                                                   2
#define RSRTM_VAL_COND_GT                                                   3

// rsrtm_rngProtocolSearchEvent
#define RSRTM_VAL_SEARCH_EVENT_FRAME                                        0
#define RSRTM_VAL_SEARCH_EVENT_ERROR                                        1
#define RSRTM_VAL_SEARCH_EVENT_ID                                           2
#define RSRTM_VAL_SEARCH_EVENT_IDDT                                         3
#define RSRTM_VAL_SEARCH_EVENT_IDERR                                        4

// rsrtm_rngProtocolLINSearchFrameSetup
#define RSRTM_VAL_LIN_SEARCH_FRAME_SOF                                      0
#define RSRTM_VAL_LIN_SEARCH_FRAME_WAKEUP                                   1

// rsrtm_rngProtocolCanLineType
#define RSRTM_VAL_CAN_LOW                                                   0
#define RSRTM_VAL_CAN_HIGH                                                  1

// rsrtm_rngProtocolCANTriggerMode
#define RSRTM_VAL_CAN_FRAME_START                                           0
#define RSRTM_VAL_CAN_FRAME_END                                             1
#define RSRTM_VAL_CAN_MSG_ID                                                2
#define RSRTM_VAL_CAN_MSG_IDDT                                              3
#define RSRTM_VAL_CAN_FRAME_TYPE                                            4
#define RSRTM_VAL_CAN_ERROR_COND                                            5

// rsrtm_rngProtocolCANTriggerFrameType
#define RSRTM_VAL_CAN_FRAME_TYPE_DATA                                       0
#define RSRTM_VAL_CAN_FRAME_TYPE_REMOTE                                     1
#define RSRTM_VAL_CAN_FRAME_TYPE_ERROR                                      2
#define RSRTM_VAL_CAN_FRAME_TYPE_OVER_LOAD                                  3
#define RSRTM_VAL_CAN_FRAME_TYPE_ANY                                        4

// rsrtm_rngProtocolCANIDType
#define RSRTM_VAL_CAN_ID_TYPE_B11                                           0
#define RSRTM_VAL_CAN_ID_TYPE_B29                                           1
#define RSRTM_VAL_CAN_ID_TYPE_ANY                                           2

// rsrtm_rngProtocolCANSearchFrameSetup
#define RSRTM_VAL_CAN_SEARCH_FRAME_SOF                                      0
#define RSRTM_VAL_CAN_SEARCH_FRAME_EOF                                      1
#define RSRTM_VAL_CAN_SEARCH_FRAME_OVER                                     2
#define RSRTM_VAL_CAN_SEARCH_FRAME_ERR                                      3
#define RSRTM_VAL_CAN_SEARCH_FRAME_DTA11                                    4
#define RSRTM_VAL_CAN_SEARCH_FRAME_DTA29                                    5
#define RSRTM_VAL_CAN_SEARCH_FRAME_REM11                                    6
#define RSRTM_VAL_CAN_SEARCH_FRAME_REM29                                    7

// rsrtm_rngProtocolCANSearchFrameType
#define RSRTM_VAL_CAN_SEARCH_FRAME_TYPE_DATA                                0
#define RSRTM_VAL_CAN_SEARCH_FRAME_TYPE_REMOTE                              1
#define RSRTM_VAL_CAN_SEARCH_FRAME_TYPE_ANY                                 2

// rsrtm_rngProtocolLINPolarity
#define RSRTM_VAL_LIN_ACTLOW                                                0
#define RSRTM_VAL_LIN_ACTHIGH                                               1
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSRTM_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSRTM_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSRTM_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSRTM_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/
#define RSRTM_VAL_CHANNEL_1   1
#define RSRTM_VAL_CHANNEL_2   2
#define RSRTM_VAL_CHANNEL_3   3
#define RSRTM_VAL_CHANNEL_4   4
#define RSRTM_VAL_CHANNEL_EXT 5

#define RSRTM_VAL_TRIGGER_A 0
#define RSRTM_VAL_TRIGGER_B 1

#define RSRTM_VAL_TRIGGER_FILTER_LOW  0
#define RSRTM_VAL_TRIGGER_FILTER_HIGH 1
    
#define RSRTM_VAL_DISPLAY_BACKGROUND 0
#define RSRTM_VAL_DISPLAY_GRID       1
#define RSRTM_VAL_DISPLAY_WAVEFORM   2

#define RSRTM_VAL_MARKER_ACTION_SET    0
#define RSRTM_VAL_MARKER_ACTION_NEXT   1
#define RSRTM_VAL_MARKER_ACTION_PREV   2
#define RSRTM_VAL_MARKER_ACTION_CLEAR  3
#define RSRTM_VAL_MARKER_ACTION_ACLEAR 4

#define RSRTM_VAL_MEASUREMENT_1 1
#define RSRTM_VAL_MEASUREMENT_2 2
#define RSRTM_VAL_MEASUREMENT_3 3
#define RSRTM_VAL_MEASUREMENT_4 4
#define RSRTM_VAL_MEASUREMENT_5 5
#define RSRTM_VAL_MEASUREMENT_6 6
#define RSRTM_VAL_MEASUREMENT_7 7
#define RSRTM_VAL_MEASUREMENT_8 8

#define RSRTM_VAL_MEASUREMENT_SOURCE_NONE 0
#define RSRTM_VAL_MEASUREMENT_SOURCE_CH1  1
#define RSRTM_VAL_MEASUREMENT_SOURCE_CH2  2
#define RSRTM_VAL_MEASUREMENT_SOURCE_CH3  3
#define RSRTM_VAL_MEASUREMENT_SOURCE_CH4  4
#define RSRTM_VAL_MEASUREMENT_SOURCE_M1   5
#define RSRTM_VAL_MEASUREMENT_SOURCE_M2   6
#define RSRTM_VAL_MEASUREMENT_SOURCE_M3   7
#define RSRTM_VAL_MEASUREMENT_SOURCE_M4   8
#define RSRTM_VAL_MEASUREMENT_SOURCE_M5   9
#define RSRTM_VAL_MEASUREMENT_SOURCE_R1   10
#define RSRTM_VAL_MEASUREMENT_SOURCE_R2   11
#define RSRTM_VAL_MEASUREMENT_SOURCE_R3   12
#define RSRTM_VAL_MEASUREMENT_SOURCE_R4   13
#define RSRTM_VAL_MEASUREMENT_SOURCE_TRIG 14

#define RSRTM_VAL_CURSOR_1 1
#define RSRTM_VAL_CURSOR_2 2
#define RSRTM_VAL_CURSOR_3 3

#define RSRTM_VAL_I2C_SCL       0
#define RSRTM_VAL_I2C_SDA       1

#define RSRTM_VAL_SPI_CLOCK  0
#define RSRTM_VAL_SPI_DATA   1
#define RSRTM_VAL_SPI_CSEL   2

#define RSRTM_VAL_PARALLEL_BIT0 0
#define RSRTM_VAL_PARALLEL_BIT1 1
#define RSRTM_VAL_PARALLEL_BIT2 2
#define RSRTM_VAL_PARALLEL_BIT3 3

#define RSRTM_VAL_WAV_LOAD      0
#define RSRTM_VAL_WAV_LOAD_CFG  1
#define RSRTM_VAL_WAV_SAVE      2

#define RSRTM_VAL_REF_WAVEFORM_1 1
#define RSRTM_VAL_REF_WAVEFORM_2 2
#define RSRTM_VAL_REF_WAVEFORM_3 3
#define RSRTM_VAL_REF_WAVEFORM_4 4

#define RSRTM_VAL_INIT_SINGLE     0
#define RSRTM_VAL_INIT_CONTINUOUS 1
    
#define RSRTM_VAL_FILE_COPY    0
#define RSRTM_VAL_FILE_MOVE    1
#define RSRTM_VAL_FILE_DELETE  2
#define RSRTM_VAL_FILE_NEW_DIR 3
#define RSRTM_VAL_FILE_CDIR    4
#define RSRTM_VAL_FILE_RDIR    5
#define RSRTM_VAL_FILE_CDRIVE  6

#define RSRTM_VAL_REG_QUES 0 
#define RSRTM_VAL_REG_OPER 1

#define RSRTM_VAL_REG_NONE     0
#define RSRTM_VAL_REG_COV      1
#define RSRTM_VAL_REG_LIM      2
#define RSRTM_VAL_REG_MASK     3
#define RSRTM_VAL_REG_NO_ALIGN 4


#define RSRTM_VAL_REG_COND   0
#define RSRTM_VAL_REG_ENABLE 1
#define RSRTM_VAL_REG_EVENT  2
#define RSRTM_VAL_REG_NTR    3
#define RSRTM_VAL_REG_PTR    4
    
#define RSRTM_VAL_MEM_SAVE    0
#define RSRTM_VAL_MEM_RECALL  1
	
#define RSRTM_VAL_MEAS_SLOPE_POS 0
#define RSRTM_VAL_MEAS_SLOPE_NEG 1
	
#define RSRTM_VAL_CURSOR_POSITION_AUTOSET  0
#define RSRTM_VAL_CURSOR_POSITION_RESET    1
	
#define RSRTM_VAL_CURSOR_PEAK_NEXT		   0
#define RSRTM_VAL_CURSOR_PEAK_PREVIOUS	   1
	
#define RSRTM_VAL_AUTOMATIC_MEASUREMENT_AVERAGE      0
#define RSRTM_VAL_AUTOMATIC_MEASUREMENT_DEVIATION    1
#define RSRTM_VAL_AUTOMATIC_MEASUREMENT_MINIMUM      2
#define RSRTM_VAL_AUTOMATIC_MEASUREMENT_MAXIMUM      3

#define RSRTM_VAL_MASK_ACTION_SOUND    0
#define RSRTM_VAL_MASK_ACTION_STOP     1
#define RSRTM_VAL_MASK_ACTION_SCREEN   2
#define RSRTM_VAL_MASK_ACTION_PRINT    3
#define RSRTM_VAL_MASK_ACTION_WAVEFORM 4

#define RSRTM_VAL_SEARCH_D2C_CLOCK 0
#define RSRTM_VAL_SEARCH_D2C_DATA  1

#define RSRTM_VAL_LIN_FIELD_SYNC   0
#define RSRTM_VAL_LIN_FIELD_CHKSUM 1

#define RSRTM_VAL_CAN_FIELD_DLC 0
#define RSRTM_VAL_CAN_FIELD_CRC 1
#define RSRTM_VAL_CAN_FIELD_ACK 2

/****************************************************************************
*---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC rsrtm_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC rsrtm_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                         ViBoolean resetDevice,
                                         ViChar _VI_FAR optionString[],
                                         ViSession* instrumentHandle);
ViStatus _VI_FUNC rsrtm_Autoset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_ConfigureAcquisitionType (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViInt32 acquisitionType);
ViStatus _VI_FUNC rsrtm_ConfigureAcquisitionRecord (ViSession instrumentHandle,
                                                    ViReal64 timePerRecord,
                                                    ViReal64 acquisitionStartTime_Offset);
ViStatus _VI_FUNC rsrtm_ConfigureTimeBase (ViSession instrumentHandle,
                                           ViReal64 timeScale,
                                           ViInt32 referencePoint);

ViStatus _VI_FUNC rsrtm_ConfigureRecordLength (ViSession instrumentHandle,
                                               ViInt32 recordLength);

ViStatus _VI_FUNC rsrtm_ConfigureRollMode (ViSession instrumentHandle,
                                           ViBoolean mode);
ViStatus _VI_FUNC rsrtm_QueryDivisions (ViSession instrumentHandle,
                                        ViInt32* divisions);
ViStatus _VI_FUNC rsrtm_QuerySampleRate (ViSession instrumentHandle,
                                         ViReal64* sampleRate);
ViStatus _VI_FUNC rsrtm_QueryAcquisitionTime (ViSession instrumentHandle,
                                              ViReal64* acquisitionTime);
ViStatus _VI_FUNC rsrtm_ConfigureWaveformAcquisitionRate (ViSession instrumentHandle,
                                                          ViInt32 waveformRate);
ViStatus _VI_FUNC rsrtm_QueryADCSampleRate (ViSession instrumentHandle,
                                            ViReal64* ADCSampleRate);
ViStatus _VI_FUNC rsrtm_ConfigureResolutionEnhancement (ViSession instrumentHandle,
                                                        ViInt32 resolutionEnhancement);
ViStatus _VI_FUNC rsrtm_ConfigureInterpolation (ViSession instrumentHandle,
                                                ViInt32 interpolation);
ViStatus _VI_FUNC rsrtm_ConfigureWaveformArithmetic (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViInt32 arithmetic);
ViStatus _VI_FUNC rsrtm_ConfigureFilterFrequency (ViSession instrumentHandle,
                                                  ViReal64 filterFrequency);
ViStatus _VI_FUNC rsrtm_QueryWaveformSamplesRange (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViInt32* samples);
ViStatus _VI_FUNC rsrtm_ConfigureNumberOfAverages (ViSession instrumentHandle,
                                                   ViInt32 numberOfAverages);
ViStatus _VI_FUNC rsrtm_ConfigureNumberOfWaveforms (ViSession instrumentHandle,
                                                    ViInt32 numberOfWaveforms);
ViStatus _VI_FUNC rsrtm_ConfigureChannel (ViSession instrumentHandle,
                                          ViInt32 channel, ViBoolean channelEnabled,
                                          ViReal64 verticalRange,
                                          ViReal64 verticalOffset,
                                          ViInt32 verticalCoupling);
ViStatus _VI_FUNC rsrtm_ConfigureChannelOffset (ViSession instrumentHandle,
                                                ViInt32 channel, ViReal64 offset);
ViStatus _VI_FUNC rsrtm_ConfigureChannelVerticalScale (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViReal64 verticalScale);
ViStatus _VI_FUNC rsrtm_ConfigureChannelThreshold (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViReal64 threshold);
ViStatus _VI_FUNC rsrtm_ConfigureChannelBandwidth (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViInt32 bandwidth);
ViStatus _VI_FUNC rsrtm_ConfigureChannelPolarity (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViInt32 polarity);
ViStatus _VI_FUNC rsrtm_ConfigureChannelOverload (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViBoolean overload);
ViStatus _VI_FUNC rsrtm_ConfigureChannelSkew (ViSession instrumentHandle,
                                              ViInt32 channel,
                                              ViReal64 deskewValue);
ViStatus _VI_FUNC rsrtm_ConfigureProbe (ViSession instrumentHandle, ViInt32 channel,
                                        ViBoolean channelVisible, ViReal64 offset);
ViStatus _VI_FUNC rsrtm_QueryProbeCharacteristics (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViInt32 bufferSize,
                                                   ViChar _VI_FAR type[],
                                                   ViChar _VI_FAR name[],
                                                   ViReal64* inputImpedance,
                                                   ViReal64* inputCapacitance,
                                                   ViChar _VI_FAR attenuation[],
                                                   ViReal64* bandwidth);
ViStatus _VI_FUNC rsrtm_ConfigureProbeMicroButtonAction (ViSession instrumentHandle,
                                                         ViInt32 channel,
                                                         ViInt32 microButtonAction);
ViStatus _VI_FUNC rsrtm_QueryProbeDCOffset (ViSession instrumentHandle,
                                            ViInt32 channel, ViReal64* DCOffset);
ViStatus _VI_FUNC rsrtm_ConfigureProbeAdditionalOffset (ViSession instrumentHandle,
                                                        ViInt32 channel,
                                                        ViReal64 probeOffset);
ViStatus _VI_FUNC rsrtm_ConfigureProbeVoltmeterState (ViSession instrumentHandle,
                                                      ViInt32 channel,
                                                      ViBoolean probeActive);
ViStatus _VI_FUNC rsrtm_ConfigureProbeAttenuationUnit (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViInt32 unit);
ViStatus _VI_FUNC rsrtm_ConfigureProbeAttenuationManual (ViSession instrumentHandle,
                                                         ViInt32 channel,
                                                         ViReal64 attenuation);
ViStatus _VI_FUNC rsrtm_QueryProbeAttributes (ViSession instrumentHandle,
                                              ViInt32 channel, ViInt32 bufferSize,
                                              ViChar _VI_FAR softwareVersion[],
                                              ViChar _VI_FAR productionDate[],
                                              ViChar _VI_FAR partNumber[],
                                              ViChar _VI_FAR serialNumber[]);
ViStatus _VI_FUNC rsrtm_QueryProbeBuildNumber (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32* buildNumber);

ViStatus _VI_FUNC rsrtm_ConfigureLabel (ViSession instrumentHandle,
                                        ViInt32 channel, ViBoolean labelState,
                                        ViString channelName);

ViStatus _VI_FUNC rsrtm_ConfigureTrigger (ViSession instrumentHandle,
                                          ViInt32 trigger, ViInt32 triggerType);
ViStatus _VI_FUNC rsrtm_ConfigureTriggerSource (ViSession instrumentHandle,
                                                ViInt32 trigger, ViInt32 channel);
ViStatus _VI_FUNC rsrtm_ConfigureExternalTriggerCoupling (ViSession instrumentHandle,
                                                          ViInt32 externalCoupling);

ViStatus _VI_FUNC rsrtm_ConfigureTriggerHoldoffTime (ViSession instrumentHandle,
                                                     ViReal64 holdoffTime);

ViStatus _VI_FUNC rsrtm_ConfigureTriggerBState (ViSession instrumentHandle,
                                                ViBoolean state);
ViStatus _VI_FUNC rsrtm_ConfigureTriggerModifier (ViSession instrumentHandle,
                                                  ViInt32 trigger,
                                                  ViInt32 triggerModifier);
ViStatus _VI_FUNC rsrtm_ConfigureTriggerEventCount (ViSession instrumentHandle,
                                                    ViInt32 eventCount);
ViStatus _VI_FUNC rsrtm_TriggerLevelAutoFind (ViSession instrumentHandle,
                                              ViInt32 trigger);
ViStatus _VI_FUNC rsrtm_ConfigureTriggerChannelLevel (ViSession instrumentHandle,
                                                      ViInt32 trigger,
                                                      ViInt32 channel,
                                                      ViReal64 triggerLevel);
ViStatus _VI_FUNC rsrtm_ConfigureTriggerHysteresis (ViSession instrumentHandle,
                                                    ViInt32 trigger,
                                                    ViInt32 hysteresis);
ViStatus _VI_FUNC rsrtm_ConfigureEdgeTriggerSource (ViSession instrumentHandle,
                                                    ViInt32 trigger,
                                                    ViInt32 channel,
                                                    ViInt32 triggerSource,
                                                    ViReal64 triggerLevel,
                                                    ViInt32 triggerSlope);
ViStatus _VI_FUNC rsrtm_ConfigureEdgeTriggerCoupling (ViSession instrumentHandle,
                                                      ViInt32 coupling);
ViStatus _VI_FUNC rsrtm_ConfigureEdgeTriggerFilter (ViSession instrumentHandle,
                                                    ViInt32 filterType,
                                                    ViBoolean filterState);
ViStatus _VI_FUNC rsrtm_ConfigureWidthTriggerSource (ViSession instrumentHandle,
                                                     ViInt32 triggerSource,
                                                     ViReal64 triggerLevel,
                                                     ViReal64 width,
                                                     ViReal64 widthDelta,
                                                     ViInt32 widthPolarity,
                                                     ViInt32 widthCondition);
ViStatus _VI_FUNC rsrtm_ConfigurePatternTriggerSource (ViSession instrumentHandle,
                                                       ViString patternSource,
                                                       ViInt32 patternFunction,
                                                       ViBoolean patternCondition);
ViStatus _VI_FUNC rsrtm_ConfigureVideoTriggerSource (ViSession instrumentHandle,
                                                     ViInt32 standard,
                                                     ViInt32 polarity,
                                                     ViInt32 field, ViInt32 line);
ViStatus _VI_FUNC rsrtm_ConfigureTriggerDelay (ViSession instrumentHandle,
                                               ViReal64 delayTime);
ViStatus _VI_FUNC rsrtm_ConfigureSignalStyle (ViSession instrumentHandle,
                                              ViInt32 style);
ViStatus _VI_FUNC rsrtm_ConfigureDisplayIntensity (ViSession instrumentHandle,
                                                   ViInt32 element,
                                                   ViReal64 intensity);
ViStatus _VI_FUNC rsrtm_ConfigureColorAndBrightness (ViSession instrumentHandle,
                                                     ViInt32 palette);
ViStatus _VI_FUNC rsrtm_ConfigureDisplayGridStyle (ViSession instrumentHandle,
                                                   ViInt32 style);
ViStatus _VI_FUNC rsrtm_ConfigureDisplayLanguage (ViSession instrumentHandle,
                                                  ViInt32 language);

ViStatus _VI_FUNC rsrtm_DisplayAddLanguage (ViSession instrumentHandle,
                                            ViInt32 language, ViString source);

ViStatus _VI_FUNC rsrtm_DisplayRemoveLanguage (ViSession instrumentHandle,
                                               ViInt32 language);

ViStatus _VI_FUNC rsrtm_ConfigureDiagramMode (ViSession instrumentHandle,
                                              ViInt32 mode);
ViStatus _VI_FUNC rsrtm_MarkerSearch (ViSession instrumentHandle,
                                      ViInt32 markerAction);
ViStatus _VI_FUNC rsrtm_ConfigurePersistence (ViSession instrumentHandle,
                                              ViBoolean enable, ViBoolean infinite,
                                              ViReal64 time);
ViStatus _VI_FUNC rsrtm_ClearPersistence (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_ConfigurePersistenceTimeAuto (ViSession instrumentHandle,
                                                      ViBoolean autoPersist);
ViStatus _VI_FUNC rsrtm_ConfigureSourceX (ViSession instrumentHandle,
                                          ViInt32 source);
ViStatus _VI_FUNC rsrtm_ConfigureSourceY1 (ViSession instrumentHandle,
                                           ViInt32 source);
ViStatus _VI_FUNC rsrtm_ConfigureSourceY2 (ViSession instrumentHandle,
                                           ViInt32 source);
ViStatus _VI_FUNC rsrtm_ConfigureIntensityControl (ViSession instrumentHandle,
                                                   ViInt32 mode);
ViStatus _VI_FUNC rsrtm_ConfigureSourceIntensity (ViSession instrumentHandle,
                                                  ViInt32 source);
ViStatus _VI_FUNC rsrtm_ConfigureIntensityTreshold (ViSession instrumentHandle,
                                                    ViReal64 treshold);
ViStatus _VI_FUNC rsrtm_ConfigureZoomWindowState (ViSession instrumentHandle,
                                                  ViBoolean zoomEnabled);
ViStatus _VI_FUNC rsrtm_ConfigureZoomReferencePoint (ViSession instrumentHandle,
                                                     ViReal64 position);
ViStatus _VI_FUNC rsrtm_ConfigureZoomDiagramTimebase (ViSession instrumentHandle,
                                                      ViReal64 scale);
ViStatus _VI_FUNC rsrtm_ConfigureZoomOffsetOfTriggerPoint
             (ViSession instrumentHandle, ViReal64 time);
ViStatus _VI_FUNC rsrtm_ConfigureMeasurement (ViSession instrumentHandle,
                                              ViInt32 measurement,
                                              ViBoolean measurementState);
ViStatus _VI_FUNC rsrtm_ConfigureMeasurementSource (ViSession instrumentHandle,
                                                    ViInt32 measurement,
                                                    ViInt32 signalSource,
                                                    ViInt32 referenceSource);
ViStatus _VI_FUNC rsrtm_ConfigureAmplitudeTimeMainMeasurement
             (ViSession instrumentHandle, ViInt32 measurement,
              ViInt32 measurementFunction);
ViStatus _VI_FUNC rsrtm_ConfigureDelayMeasuremenSlope (ViSession instrumentHandle,
                                                       ViInt32 measurement,
                                                       ViInt32 source1Slope,
                                                       ViInt32 source2Slope);
ViStatus _VI_FUNC rsrtm_QueryMeasurementCategory (ViSession instrumentHandle,
                                                  ViInt32 measurement,
                                                  ViInt32* category);
ViStatus _VI_FUNC rsrtm_ConfigureReferenceLevelMode (ViSession instrumentHandle,
                                                     ViInt32 relativeMode);
ViStatus _VI_FUNC rsrtm_ConfigureUserReferenceLevel (ViSession instrumentHandle,
                                                     ViReal64 lowerLevel,
                                                     ViReal64 upperLevel,
                                                     ViReal64 middleLevel);
ViStatus _VI_FUNC rsrtm_ConfigureCursor (ViSession instrumentHandle,
                                         ViBoolean cursorState, ViInt32 source,
                                         ViInt32 type);
ViStatus _VI_FUNC rsrtm_AllCursorsOff (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_ConfigureCursorPosition (ViSession instrumentHandle,
                                                 ViInt32 cursor, ViReal64 xPosition,
                                                 ViReal64 yPosition);
ViStatus _VI_FUNC rsrtm_ConfigureCursorCoupling (ViSession instrumentHandle,
                                                 ViBoolean xCoupling,
                                                 ViBoolean yCoupling);
ViStatus _VI_FUNC rsrtm_SetCursorPosition (ViSession instrumentHandle,
                                           ViInt32 cursor, ViInt32 position);
ViStatus _VI_FUNC rsrtm_SetFFTAnalysisCursorToPeak (ViSession instrumentHandle,
                                                    ViInt32 cursor, ViInt32 peak);
ViStatus _VI_FUNC rsrtm_ConfigureCursorWaveformTracking (ViSession instrumentHandle,
                                                         ViBoolean tracking);
ViStatus _VI_FUNC rsrtm_ConfigureCursorAdjustment (ViSession instrumentHandle,
                                                   ViBoolean adjustment);
ViStatus _VI_FUNC rsrtm_ConfigureCursorRatioMeasurementUnit
             (ViSession instrumentHandle, ViInt32 direction,
              ViInt32 measurementUnit);
ViStatus _VI_FUNC rsrtm_QueryCursorRatioMeasurement (ViSession instrumentHandle,
                                                     ViInt32 direction,
                                                     ViReal64* ratioMeasurement);
ViStatus _VI_FUNC rsrtm_QueryCursorDistance (ViSession instrumentHandle,
                                             ViInt32 direction,
                                             ViReal64* cursorDistance);
ViStatus _VI_FUNC rsrtm_QueryCursorInverseDistance (ViSession instrumentHandle,
                                                    ViReal64* cursorDistance);
ViStatus _VI_FUNC rsrtm_QueryCursorVoltageInverseDistance
             (ViSession instrumentHandle, ViReal64* cursorDistance);
ViStatus _VI_FUNC rsrtm_QueryCursorPosition (ViSession instrumentHandle,
                                             ViReal64* data);
ViStatus _VI_FUNC rsrtm_ConfigureCursorPeakExcursion (ViSession instrumentHandle,
                                                      ViInt32 peakExcursion);
ViStatus _VI_FUNC rsrtm_ConfigureQuickMeasurements (ViSession instrumentHandle,
                                                    ViInt32 measurement,
                                                    ViBoolean quickMeasurementsEnabled);

ViStatus _VI_FUNC rsrtm_ConfigureQuickMeasurementsWithStatusBit (ViSession instrumentHandle,
                                                                 ViInt32 measurement,
                                                                 ViBoolean quickMeasurementsEnabled);

ViStatus _VI_FUNC rsrtm_QueryQuickMeasurementResults (ViSession instrumentHandle,
                                                      ViInt32 measurement,
                                                      ViInt32 arraySize,
                                                      ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC rsrtm_ConfigureAutomaticMeasurement (ViSession instrumentHandle,
                                                       ViInt32 measurement,
                                                       ViBoolean state,
                                                       ViInt32 numberOfWaveforms);
ViStatus _VI_FUNC rsrtm_ResetAutomaticMeasurement (ViSession instrumentHandle,
                                                   ViInt32 measurement);
ViStatus _VI_FUNC rsrtm_QueryAutomaticMeasurementNumberOfWaveforms
             (ViSession instrumentHandle, ViInt32 measurement,
              ViInt32* numberOfWaveforms);
ViStatus _VI_FUNC rsrtm_QueryAutomaticMeasurementResult (ViSession instrumentHandle,
                                                         ViInt32 measurement,
                                                         ViInt32 resultType,
                                                         ViReal64* result);

ViStatus _VI_FUNC rsrtm_QueryAutomaticMeasurementSingleStatisticalValue (ViSession instrumentHandle,
                                                                         ViInt32 measurement,
                                                                         ViInt32 bufferPosition,
                                                                         ViReal64 *value);

ViStatus _VI_FUNC rsrtm_QueryAutomaticMeasurementAllStatisticalValues (ViSession instrumentHandle,
                                                                       ViInt32 measurement,
                                                                       ViInt32 arraySize,
                                                                       ViReal64 results[]);

ViStatus _VI_FUNC rsrtm_SampleMode (ViSession instrumentHandle,
                                    ViInt32* sampleMode);
ViStatus _VI_FUNC rsrtm_ActualSampleRate (ViSession instrumentHandle,
                                          ViReal64* sampleRate);
ViStatus _VI_FUNC rsrtm_AutoProbeSenseValue (ViSession instrumentHandle,
                                             ViInt32 channel, ViInt32 bufferSize,
                                             ViChar _VI_FAR autoProbeSenseValue[]);
ViStatus _VI_FUNC rsrtm_ConfigureMaskTestEnable (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rsrtm_ConfigureMaskTest (ViSession instrumentHandle,
                                           ViInt32 source, ViInt32 action);

ViStatus _VI_FUNC rsrtm_ConfigureMaskTestAction (ViSession instrumentHandle,
                                                 ViInt32 action,
                                                 ViInt32 execution,
                                                 ViInt32 violationCount);

ViStatus _VI_FUNC rsrtm_MaskCopyChannel (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_MaskLoad (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC rsrtm_MaskStore (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC rsrtm_ConfigureMaskVerticalOffset (ViSession instrumentHandle,
                                                     ViReal64 yPosition);
ViStatus _VI_FUNC rsrtm_ConfigureMaskVerticalScaling (ViSession instrumentHandle,
                                                      ViReal64 yStretch);
ViStatus _VI_FUNC rsrtm_ConfigureMaskVerticalWidth (ViSession instrumentHandle,
                                                    ViReal64 yWidth);
ViStatus _VI_FUNC rsrtm_ConfigureMaskHorizontalWidth (ViSession instrumentHandle,
                                                      ViReal64 xWidth);
ViStatus _VI_FUNC rsrtm_QueryMaskAcquisitions (ViSession instrumentHandle,
                                               ViInt32* totalCount);
ViStatus _VI_FUNC rsrtm_QueryMaskHitCount (ViSession instrumentHandle,
                                           ViInt32* acquistions);

ViStatus _VI_FUNC rsrtm_MaskResetTestCounter (ViSession instrumentHandle);

ViStatus _VI_FUNC rsrtm_ConfigureSearchState (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rsrtm_ConfigureSearchCondition (ViSession instrumentHandle,
                                                  ViInt32 action);
ViStatus _VI_FUNC rsrtm_ConfigureSearchSource (ViSession instrumentHandle,
                                               ViInt32 searchSource);
ViStatus _VI_FUNC rsrtm_ConfigureEdgeTriggerSearch (ViSession instrumentHandle,
                                                    ViInt32 triggerSlope,
                                                    ViReal64 triggerLevel,
                                                    ViReal64 triggerHystersis);
ViStatus _VI_FUNC rsrtm_ConfigureWidthTriggerSearch (ViSession instrumentHandle,
                                                     ViReal64 level,
                                                     ViReal64 levelDelta,
                                                     ViReal64 width,
                                                     ViReal64 widthDelta,
                                                     ViInt32 polarity,
                                                     ViInt32 range);
ViStatus _VI_FUNC rsrtm_ConfigurePeakTriggerSearch (ViSession instrumentHandle,
                                                    ViInt32 polarity,
                                                    ViReal64 limit);
ViStatus _VI_FUNC rsrtm_ConfigureRiseTimeTriggerSearch (ViSession instrumentHandle,
                                                        ViInt32 polarity,
                                                        ViReal64 upperLevel,
                                                        ViReal64 lowerLevel,
                                                        ViInt32 range,
                                                        ViReal64 time,
                                                        ViReal64 deltaTime);
ViStatus _VI_FUNC rsrtm_ConfigureRuntTriggerSearch (ViSession instrumentHandle,
                                                    ViInt32 polarity,
                                                    ViReal64 upperLevel,
                                                    ViReal64 lowerLevel,
                                                    ViInt32 range, ViReal64 width,
                                                    ViReal64 deltaWidth);

ViStatus _VI_FUNC rsrtm_ConfigureData2ClockTriggerSearchSource (ViSession instrumentHandle,
                                                                ViInt32 line,
                                                                ViInt32 source,
                                                                ViReal64 level,
                                                                ViReal64 hysteresis);

ViStatus _VI_FUNC rsrtm_ConfigureData2ClockTriggerSearch (ViSession instrumentHandle,
                                                          ViInt32 polarity,
                                                          ViReal64 setupTime,
                                                          ViReal64 holdTime);

ViStatus _VI_FUNC rsrtm_ConfigurePatternTriggerSearchSource (ViSession instrumentHandle,
                                                             ViInt32 source,
                                                             ViReal64 level,
                                                             ViReal64 hysteresis);

ViStatus _VI_FUNC rsrtm_ConfigurePatternTriggerSearch (ViSession instrumentHandle,
                                                       ViString channelPattern,
                                                       ViInt32 combiation,
                                                       ViInt32 comparison,
                                                       ViReal64 width,
                                                       ViReal64 variation);

ViStatus _VI_FUNC rsrtm_ConfigureSearchGate (ViSession instrumentHandle,
                                             ViInt32 mode, ViReal64 start,
                                             ViReal64 stop);

ViStatus _VI_FUNC rsrtm_ConfigureShowResultDiagram (ViSession instrumentHandle,
                                                    ViBoolean showResult);
ViStatus _VI_FUNC rsrtm_QueryNumberOfResults (ViSession instrumentHandle,
                                              ViInt32* numberOfResults);
ViStatus _VI_FUNC rsrtm_QuerySearchResult (ViSession instrumentHandle,
                                           ViInt32 resultNumber,
                                           ViReal64* xPosition, ViReal64* yPosition,
                                           ViInt32* resultType, ViInt32* polarity,
                                           ViReal64* voltageWidth);
ViStatus _VI_FUNC rsrtm_QueryAllSearchResults (ViSession instrumentHandle,
                                               ViInt32 arraySize,
                                               ViReal64 _VI_FAR xPosition[],
                                               ViReal64 _VI_FAR yPosition[],
                                               ViInt32 _VI_FAR resultType[],
                                               ViInt32 _VI_FAR polarity[],
                                               ViReal64 _VI_FAR voltageWidth[],
                                               ViInt32* numberOfResults);
ViStatus _VI_FUNC rsrtm_ConfigureDecodeState (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rsrtm_ConfigureBusProtocol (ViSession instrumentHandle,
                                              ViInt32 protocol);
ViStatus _VI_FUNC rsrtm_ConfigureProtocolDisplay (ViSession instrumentHandle,
                                                  ViInt32 format, ViInt32 height,
                                                  ViBoolean displayLines,
                                                  ViReal64 verticalPosition);

ViStatus _VI_FUNC rsrtm_ProtocolFindLevel (ViSession instrumentHandle,
                                           ViInt32 channel);

ViStatus _VI_FUNC rsrtm_QueryBusDecodedData (ViSession instrumentHandle,
                                             ViInt32 bufferSize,
                                             ViChar decodedData[]);

ViStatus _VI_FUNC rsrtm_SaveBusDecodedData (ViSession instrumentHandle,
                                            ViString filePath);

ViStatus _VI_FUNC rsrtm_ConfigureI2CSource (ViSession instrumentHandle,
                                            ViInt32 line, ViInt32 waveformSource);
ViStatus _VI_FUNC rsrtm_ConfigureI2CTriggerSetting (ViSession instrumentHandle,
                                                    ViInt32 access,
                                                    ViInt32 addressLength,
                                                    ViString deviceAddress,
                                                    ViInt32 triggerMode,
                                                    ViInt32 patternLength,
                                                    ViString pattern,
                                                    ViInt32 patternOffset);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameCount (ViSession instrumentHandle,
                                            ViInt32 *count);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameStatus (ViSession instrumentHandle,
                                             ViInt32 frame, ViInt32 *status,
                                             ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *addresType,
                                             ViInt32 *address, ViInt32 *RWBit,
                                             ViInt32 *ackBit);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameSlaveAddress (ViSession instrumentHandle,
                                                   ViInt32 frame,
                                                   ViInt32 *address);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameAddressStartTime (ViSession instrumentHandle,
                                                             ViInt32 frame,
                                                             ViReal64 *addressStart);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameAddressAckBitStart (ViSession instrumentHandle,
                                                         ViInt32 frame,
                                                         ViReal64 *ackBitStart);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameAddressComplete (ViSession instrumentHandle,
                                                      ViInt32 frame,
                                                      ViBoolean *complete);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameLength (ViSession instrumentHandle,
                                             ViInt32 frame, ViInt32 *length);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameData (ViSession instrumentHandle,
                                           ViInt32 frame, ViInt32 byteNumber,
                                           ViInt32 *data, ViInt32 *ackBit);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameAcknowledgeByteStart (ViSession instrumentHandle,
                                                           ViInt32 frame,
                                                           ViInt32 byteNumber,
                                                           ViReal64 *startTime);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameDataByteStart (ViSession instrumentHandle,
                                                    ViInt32 frame,
                                                    ViInt32 byteNumber,
                                                    ViReal64 *startTime);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameDataComplete (ViSession instrumentHandle,
                                                   ViInt32 frame,
                                                   ViInt32 byteNumber,
                                                   ViBoolean *complete);

ViStatus _VI_FUNC rsrtm_QueryI2CFrameAllData (ViSession instrumentHandle,
                                              ViInt32 frame, ViInt32 arraySize,
                                              ViInt32 data[],
                                              ViInt32 *returnedValues);

ViStatus _VI_FUNC rsrtm_ConfigureSPISource (ViSession instrumentHandle,
                                            ViInt32 line, ViInt32 waveformSource);
ViStatus _VI_FUNC rsrtm_ConfigureSPIPolarity (ViSession instrumentHandle,
                                              ViInt32 line, ViInt32 polarity);
ViStatus _VI_FUNC rsrtm_ConfigureSPIWord (ViSession instrumentHandle,
                                          ViInt32 bitOrder, ViInt32 wordLength);

ViStatus _VI_FUNC rsrtm_ConfigureSPITriggerSource (ViSession instrumentHandle,
                                                   ViInt32 line);

ViStatus _VI_FUNC rsrtm_ConfigureSPITriggerType (ViSession instrumentHandle,
                                                 ViInt32 mode);
ViStatus _VI_FUNC rsrtm_ConfigureSPITriggerData (ViSession instrumentHandle,
                                                 ViInt32 offset,
                                                 ViInt32 bitPatternLength,
                                                 ViString bitPattern);
ViStatus _VI_FUNC rsrtm_ConfigureSSPISource (ViSession instrumentHandle,
                                             ViInt32 line, ViInt32 waveformSource);
ViStatus _VI_FUNC rsrtm_ConfigureSSPIPolarity (ViSession instrumentHandle,
                                               ViInt32 line, ViInt32 polarity);
ViStatus _VI_FUNC rsrtm_ConfigureSSPIPackets (ViSession instrumentHandle,
                                              ViReal64 interframeTime,
                                              ViInt32 bitOrder, ViInt32 wordLength);

ViStatus _VI_FUNC rsrtm_QuerySPIFrameCount (ViSession instrumentHandle,
                                            ViInt32 *count);

ViStatus _VI_FUNC rsrtm_QuerySPIWordCount (ViSession instrumentHandle,
                                           ViInt32 frame, ViInt32 *count);

ViStatus _VI_FUNC rsrtm_QuerySPIFrameStatus (ViSession instrumentHandle,
                                             ViInt32 frame, ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *status);

ViStatus _VI_FUNC rsrtm_QuerySPIFrameData (ViSession instrumentHandle,
                                           ViInt32 frame, ViInt32 word,
                                           ViReal64 *valueStart,
                                           ViReal64 *valueStop,
                                           ViInt32 *MOSIValue,
                                           ViInt32 *MISOValue);

ViStatus _VI_FUNC rsrtm_QuerySPIFrameAllData (ViSession instrumentHandle,
                                              ViInt32 line, ViInt32 frame,
                                              ViInt32 arraySize, ViInt32 data[],
                                              ViInt32 *returnedValues);

ViStatus _VI_FUNC rsrtm_ConfigureUARTSource (ViSession instrumentHandle,
                                             ViInt32 waveformSource);

ViStatus _VI_FUNC rsrtm_ConfigureUARTSourceLine (ViSession instrumentHandle,
                                                 ViInt32 line,
                                                 ViInt32 waveformSource);

ViStatus _VI_FUNC rsrtm_ConfigureUARTPolarity (ViSession instrumentHandle,
                                               ViInt32 polarity);
ViStatus _VI_FUNC rsrtm_ConfigureUART (ViSession instrumentHandle,
                                       ViReal64 interframeTime, ViInt32 wordLength,
                                       ViInt32 bitRate, ViInt32 parity,
                                       ViInt32 stopBits);

ViStatus _VI_FUNC rsrtm_ConfigureUARTTriggerSource (ViSession instrumentHandle,
                                                    ViInt32 line);

ViStatus _VI_FUNC rsrtm_ConfigureUARTTriggerType (ViSession instrumentHandle,
                                                  ViInt32 mode);
ViStatus _VI_FUNC rsrtm_ConfigureUARTTriggerPattern (ViSession instrumentHandle,
                                                     ViString pattern,
                                                     ViInt32 patternLength,
                                                     ViInt32 patternOffset);

ViStatus _VI_FUNC rsrtm_QueryUARTFrameCount (ViSession instrumentHandle,
                                             ViInt32 line, ViInt32 *count);

ViStatus _VI_FUNC rsrtm_QueryUARTWordCount (ViSession instrumentHandle,
                                            ViInt32 line, ViInt32 frame,
                                            ViInt32 *count);
ViStatus _VI_FUNC rsrtm_QueryUARTFrameData (ViSession instrSession,
                                            ViInt32 line, ViInt32 frame, ViInt32 word,
                                            ViInt32 *status, ViReal64 *start, 
                                            ViReal64 *stop, ViInt32 *value);

ViStatus _VI_FUNC rsrtm_ConfigureLINSource (ViSession instrumentHandle,
                                            ViInt32 waveformSource);

ViStatus _VI_FUNC rsrtm_ConfigureLINPolarity (ViSession instrumentHandle,
                                              ViInt32 polarity);

ViStatus _VI_FUNC rsrtm_ConfigureLINStandard (ViSession instrumentHandle,
                                              ViInt32 standard, ViInt32 bitRate);

ViStatus _VI_FUNC rsrtm_ConfigureLINTriggerType (ViSession instrumentHandle,
                                                 ViInt32 type);

ViStatus _VI_FUNC rsrtm_ConfigureLINTriggerID (ViSession instrumentHandle,
                                               ViInt32 condition,
                                               ViString identifier);

ViStatus _VI_FUNC rsrtm_ConfigureLINTriggerData (ViSession instrumentHandle,
                                                 ViInt32 condition,
												 ViInt32 dataLength,
                                                 ViString dataPattern);

ViStatus _VI_FUNC rsrtm_ConfigureLINTriggerErrorConditions (ViSession instrumentHandle,
                                                            ViBoolean checksum,
                                                            ViBoolean parityError,
                                                            ViBoolean syncError);

ViStatus _VI_FUNC rsrtm_QueryLINFrameCount (ViSession instrumentHandle,
                                            ViInt32 *count);

ViStatus _VI_FUNC rsrtm_QueryLINFrameStatus (ViSession instrumentHandle,
                                             ViInt32 frame, ViInt32 *frameStatus,
                                             ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *version);

ViStatus _VI_FUNC rsrtm_QueryLINFrameID (ViSession instrumentHandle,
                                         ViInt32 frame, ViInt32 *value,
                                         ViInt32 *parity, ViInt32 *status);

ViStatus _VI_FUNC rsrtm_QueryLINFrameField (ViSession instrumentHandle,
                                            ViInt32 frame, ViInt32 field,
                                            ViInt32 *fieldValue,
                                            ViInt32 *fieldStatus);

ViStatus _VI_FUNC rsrtm_QueryLINFrameByteCount (ViSession instrumentHandle,
                                                ViInt32 frame,
                                                ViInt32 *byteCount);

ViStatus _VI_FUNC rsrtm_QueryLINFrameData (ViSession instrumentHandle,
                                           ViInt32 frame, ViInt32 byteNumber,
                                           ViInt32 *data, ViInt32 *statusCode);

ViStatus _VI_FUNC rsrtm_QueryLINFrameAllData (ViSession instrumentHandle,
                                              ViInt32 frame, ViInt32 arraySize,
                                              ViInt32 data[],
                                              ViInt32 *returnedValues);

ViStatus _VI_FUNC rsrtm_ConfigureLINSearchEvent (ViSession instrumentHandle,
                                                 ViInt32 event);

ViStatus _VI_FUNC rsrtm_ConfigureLINSearchFrameSetup (ViSession instrumentHandle,
                                                      ViInt32 frameSetup);

ViStatus _VI_FUNC rsrtm_ConfigureLINSearchID (ViSession instrumentHandle,
                                              ViInt32 condition,
                                              ViString identifier);

ViStatus _VI_FUNC rsrtm_ConfigureLINSearchData (ViSession instrumentHandle,
												ViInt32 condition,
                                                ViInt32 dataLength,
                                                ViString dataPattern);

ViStatus _VI_FUNC rsrtm_ConfigureLINSearchErrorConditions (ViSession instrumentHandle,
                                                           ViBoolean checksum,
                                                           ViBoolean parityError,
                                                           ViBoolean syncError);

ViStatus _VI_FUNC rsrtm_ConfigureCANSource (ViSession instrumentHandle,
                                            ViInt32 line, ViInt32 waveformSource);

ViStatus _VI_FUNC rsrtm_ConfigureCANBitRate (ViSession instrumentHandle,
                                             ViInt32 bitRate);

ViStatus _VI_FUNC rsrtm_ConfigureCANSamplePoint (ViSession instrumentHandle,
                                                 ViReal64 samplePoint);

ViStatus _VI_FUNC rsrtm_ConfigureCANTriggerType (ViSession instrumentHandle,
                                                 ViInt32 type, ViInt32 frameType);

ViStatus _VI_FUNC rsrtm_ConfigureCANTriggerID (ViSession instrumentHandle,
                                               ViInt32 IDType, ViInt32 condition,
                                               ViString identifier);

ViStatus _VI_FUNC rsrtm_QueryCANFrameCount (ViSession instrumentHandle,
                                            ViInt32 *count);

ViStatus _VI_FUNC rsrtm_QueryCANFrameStatus (ViSession instrumentHandle,
                                             ViInt32 frame, ViInt32 *frameStatus,
                                             ViReal64 *frameStart,
                                             ViReal64 *frameStop,
                                             ViInt32 *frameType);

ViStatus _VI_FUNC rsrtm_QueryCANFrameID (ViSession instrumentHandle,
                                         ViInt32 frame, ViInt32 *IDType,
                                         ViInt32 *IDValue, ViInt32 *statusCode);

ViStatus _VI_FUNC rsrtm_QueryCANFrameField (ViSession instrumentHandle,
                                            ViInt32 frame, ViInt32 field,
                                            ViInt32 *fieldValue,
                                            ViInt32 *fieldStatus);

ViStatus _VI_FUNC rsrtm_QueryCANFrameByteCount (ViSession instrumentHandle,
                                                ViInt32 frame,
                                                ViInt32 *byteCount);

ViStatus _VI_FUNC rsrtm_QueryCANFrameBitStuffingError (ViSession instrumentHandle,
                                                       ViInt32 frame,
                                                       ViReal64 *errorPosition);

ViStatus _VI_FUNC rsrtm_QueryCANFrameData (ViSession instrumentHandle,
                                           ViInt32 frame, ViInt32 byteNumber,
                                           ViInt32 *data, ViInt32 *statusCode);

ViStatus _VI_FUNC rsrtm_QueryCANFrameAllData (ViSession instrumentHandle,
                                              ViInt32 frame, ViInt32 arraySize,
                                              ViInt32 data[],
                                              ViInt32 *returnedValues);

ViStatus _VI_FUNC rsrtm_ConfigureCANSearchEvent (ViSession instrumentHandle,
                                                 ViInt32 event);

ViStatus _VI_FUNC rsrtm_ConfigureCANSearchFrameSetup (ViSession instrumentHandle,
                                                      ViInt32 frameSetup);

ViStatus _VI_FUNC rsrtm_ConfigureCANSearchFrameType (ViSession instrumentHandle,
                                                     ViInt32 frameType);

ViStatus _VI_FUNC rsrtm_ConfigureCANSearchID (ViSession instrumentHandle,
                                              ViInt32 IDType, ViInt32 condition,
                                              ViString identifier);

ViStatus _VI_FUNC rsrtm_ConfigureCANTriggerData (ViSession instrSession,
												 ViInt32 condition,
                                                 ViInt32 dataLength,
												 ViString dataPattern);

ViStatus _VI_FUNC rsrtm_ConfigureCANTriggerErrorConditions (ViSession instrumentHandle,
                                                            ViBoolean CRC,
                                                            ViBoolean stuffing,
                                                            ViBoolean form,
                                                            ViBoolean ack);

ViStatus _VI_FUNC rsrtm_ConfigureCANSearchData (ViSession instrumentHandle,
                                                ViInt32 condition,
                                                ViInt32 dataLength,
                                                ViString dataPattern);

ViStatus _VI_FUNC rsrtm_ConfigureCANSearchErrorConditions (ViSession instrumentHandle,
                                                           ViBoolean CRC,
                                                           ViBoolean stuffing,
                                                           ViBoolean form,
                                                           ViBoolean ack);
ViStatus _VI_FUNC rsrtm_ConfigureParallelAnalyzedLines (ViSession instrSession,
                                                        ViInt32 line);
ViStatus _VI_FUNC rsrtm_ConfigureHardcopyPrinter (ViSession instrumentHandle,
                                                  ViString printerName,
                                                  ViInt32 pageOrientation,
                                                  ViInt32 scheme, ViInt32 size);
ViStatus _VI_FUNC rsrtm_ConfigureHardcopyFile (ViSession instrumentHandle,
                                               ViString name, ViInt32 format,
                                               ViInt32 scheme);
ViStatus _VI_FUNC rsrtm_HardcopyPrint (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_HardcopyGetPrinterList (ViSession instrumentHandle,
                                                ViInt32 bufferSize,
                                                ViChar _VI_FAR printerList[]);
ViStatus _VI_FUNC rsrtm_SetAttributeViInt32 (ViSession instrumentHandle,
                                             ViChar _VI_FAR channelName[],
                                             ViAttr attributeID,
                                             ViInt32 attributeValue);
ViStatus _VI_FUNC rsrtm_SetAttributeViReal64 (ViSession instrumentHandle,
                                              ViChar _VI_FAR channelName[],
                                              ViAttr attributeID,
                                              ViReal64 attributeValue);
ViStatus _VI_FUNC rsrtm_SetAttributeViString (ViSession instrumentHandle,
                                              ViChar _VI_FAR channelName[],
                                              ViAttr attributeID,
                                              ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rsrtm_SetAttributeViBoolean (ViSession instrumentHandle,
                                               ViChar _VI_FAR channelName[],
                                               ViAttr attributeID,
                                               ViBoolean attributeValue);
ViStatus _VI_FUNC rsrtm_SetAttributeViSession (ViSession instrumentHandle,
                                               ViChar _VI_FAR channelName[],
                                               ViAttr attributeID,
                                               ViSession attributeValue);
ViStatus _VI_FUNC rsrtm_GetAttributeViInt32 (ViSession instrumentHandle,
                                             ViChar _VI_FAR channelName[],
                                             ViAttr attributeID,
                                             ViInt32* attributeValue);
ViStatus _VI_FUNC rsrtm_GetAttributeViReal64 (ViSession instrumentHandle,
                                              ViChar _VI_FAR channelName[],
                                              ViAttr attributeID,
                                              ViReal64* attributeValue);
ViStatus _VI_FUNC rsrtm_GetAttributeViString (ViSession instrumentHandle,
                                              ViChar _VI_FAR channelName[],
                                              ViAttr attributeID,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rsrtm_GetAttributeViBoolean (ViSession instrumentHandle,
                                               ViChar _VI_FAR channelName[],
                                               ViAttr attributeID,
                                               ViBoolean* attributeValue);
ViStatus _VI_FUNC rsrtm_GetAttributeViSession (ViSession instrumentHandle,
                                               ViChar _VI_FAR channelName[],
                                               ViAttr attributeID,
                                               ViSession* attributeValue);
ViStatus _VI_FUNC rsrtm_CheckAttributeViInt32 (ViSession instrumentHandle,
                                               ViChar _VI_FAR channelName[],
                                               ViAttr attributeID,
                                               ViInt32 attributeValue);
ViStatus _VI_FUNC rsrtm_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                ViChar _VI_FAR channelName[],
                                                ViAttr attributeID,
                                                ViReal64 attributeValue);
ViStatus _VI_FUNC rsrtm_CheckAttributeViString (ViSession instrumentHandle,
                                                ViChar _VI_FAR channelName[],
                                                ViAttr attributeID,
                                                ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rsrtm_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                 ViChar _VI_FAR channelName[],
                                                 ViAttr attributeID,
                                                 ViBoolean attributeValue);
ViStatus _VI_FUNC rsrtm_CheckAttributeViSession (ViSession instrumentHandle,
                                                 ViChar _VI_FAR channelName[],
                                                 ViAttr attributeID,
                                                 ViSession attributeValue);
ViStatus _VI_FUNC rsrtm_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rsrtm_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rsrtm_ConfigureMathEnabled (ViSession instrumentHandle,
                                              ViInt32 mathNumber,
                                              ViBoolean mathEnabled);
ViStatus _VI_FUNC rsrtm_ConfigureMathWaveformPosition (ViSession instrumentHandle,
                                                       ViInt32 mathNumber,
                                                       ViReal64 waveformPosition);
ViStatus _VI_FUNC rsrtm_ConfigureMathScaling (ViSession instrumentHandle,
                                              ViInt32 mathNumber,
                                              ViReal64 verticalScale);
ViStatus _VI_FUNC rsrtm_ConfigureMathSetup (ViSession instrumentHandle,
                                            ViInt32 mathNumber,
                                            ViInt32 calculationMethod,
                                            ViString expression);
ViStatus _VI_FUNC rsrtm_ConfigureFFTFrequencyCenterSpan (ViSession instrumentHandle,
                                                         ViInt32 mathNumber,
                                                         ViReal64 centerFrequency,
                                                         ViReal64 frequencySpan);
ViStatus _VI_FUNC rsrtm_ConfigureFFTFrequencySpanFull (ViSession instrumentHandle,
                                                       ViInt32 mathNumber);
ViStatus _VI_FUNC rsrtm_ConfigureFFTFrequencyStartStop (ViSession instrumentHandle,
                                                        ViInt32 mathNumber,
                                                        ViReal64 startFrequency,
                                                        ViReal64 stopFrequency);
ViStatus _VI_FUNC rsrtm_ConfigureFFTResolutionBandwidth (ViSession instrumentHandle,
                                                         ViInt32 mathNumber,
                                                         ViBoolean RBWAndSpanCouplingEnabled,
                                                         ViInt32 RBWRatio,
                                                         ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsrtm_QueryFFTAdjustedResolutionBandwidth
             (ViSession instrumentHandle, ViInt32 mathNumber,
              ViReal64* adjustedRBW);
ViStatus _VI_FUNC rsrtm_ConfigureFFTWindowType (ViSession instrumentHandle,
                                                ViInt32 mathNumber,
                                                ViInt32 windowType);
ViStatus _VI_FUNC rsrtm_ConfigureFFTAveraging (ViSession instrumentHandle,
                                               ViInt32 mathNumber,
                                               ViInt32 numberOfSpectrums);
ViStatus _VI_FUNC rsrtm_ConfigureFFTScaling (ViSession instrumentHandle,
                                             ViInt32 mathNumber,
                                             ViInt32 scalingUnit,
                                             ViReal64 verticalScale);

ViStatus _VI_FUNC rsrtm_ConfigureFFTYtWindowExtract (ViSession instrumentHandle,
                                                     ViInt32 mathNumber,
                                                     ViReal64 position,
                                                     ViReal64 width);

ViStatus _VI_FUNC rsrtm_QueryFFTSampleRate (ViSession instrumentHandle,
                                            ViInt32 mathNumber,
                                            ViInt32* sampleRate);
ViStatus _VI_FUNC rsrtm_ConfigureReferenceWaveformSource (ViSession instrumentHandle,
                                                          ViInt32 referenceNumber,
                                                          ViInt32 source);
ViStatus _VI_FUNC rsrtm_UpdateReferenceWaveformWithSelectedSource
             (ViSession instrumentHandle, ViInt32 referenceNumber);
ViStatus _VI_FUNC rsrtm_ConfigureReferenceWaveformDisplayState
             (ViSession instrumentHandle, ViInt32 referenceNumber,
              ViBoolean displayEnabled);
ViStatus _VI_FUNC rsrtm_ReferenceWaveformFileOperations (ViSession instrumentHandle,
                                                         ViInt32 referenceWfm,
                                                         ViInt32 operation,
                                                         ViString fileName);
ViStatus _VI_FUNC rsrtm_ConfigureReferenceWaveformVerticalScale
             (ViSession instrumentHandle, ViInt32 referenceNumber,
              ViReal64 verticalScale, ViReal64 verticalPosition);
ViStatus _VI_FUNC rsrtm_ConfigureReferenceWaveformHorizontalScale
             (ViSession instrumentHandle, ViInt32 referenceWfm, ViReal64 scale,
              ViReal64 horizontalPosition);
ViStatus _VI_FUNC rsrtm_ReferenceReadWaveformCatalog (ViSession instrumentHandle,
                                                      ViInt32 referenceWfm,
                                                      ViInt32* sourceWaveform);
ViStatus _VI_FUNC rsrtm_ReadWaveform (ViSession instrumentHandle, ViInt32 channel,
                                      ViInt32 waveformSize, ViInt32 maximumTime,
                                      ViReal64 _VI_FAR waveformArray[],
                                      ViInt32* actualPoints, ViReal64* initialX,
                                      ViReal64* xIncrement);
ViStatus _VI_FUNC rsrtm_ReadMainWaveformMeasurement (ViSession instrumentHandle,
                                                     ViInt32 measurement,
                                                     ViInt32 measurementFunction,
                                                     ViInt32 maximumTime,
                                                     ViReal64* measurementResult);
ViStatus _VI_FUNC rsrtm_InitiateAcquisition (ViSession instrumentHandle,
                                             ViInt32 action);
ViStatus _VI_FUNC rsrtm_SendSoftwareTrigger (ViSession instrumentHandle,
                                             ViInt32 maximumTime);
ViStatus _VI_FUNC rsrtm_FetchWaveform (ViSession instrumentHandle, ViInt32 channel,
                                       ViInt32 waveformSize,
                                       ViReal64 _VI_FAR waveformArray[],
                                       ViInt32* actualPoints, ViReal64* initialX,
                                       ViReal64* xIncrement);

ViStatus _VI_FUNC rsrtm_FetchWaveformInteger (ViSession instrumentHandle,
                                              ViInt32 channel,
                                              ViInt32 waveformSize,
                                              ViUInt16 waveformArray[],
                                              ViInt32 *actualPoints,
                                              ViReal64 *initialX,
                                              ViReal64 *xIncrement);

ViStatus _VI_FUNC rsrtm_FetchWaveformByte (ViSession instrumentHandle,
                                           ViInt32 channel, ViInt32 waveformSize,
                                           ViByte waveformArray[],
                                           ViInt32 *actualPoints,
                                           ViReal64 *initialX,
                                           ViReal64 *xIncrement);

ViStatus _VI_FUNC rsrtm_FetchWaveformHeader (ViSession instrumentHandle,
                                             ViInt32 channel, ViReal64* xStart,
                                             ViReal64* xStop, ViInt32* recordLength,
                                             ViInt32* valuesPerSample);

ViStatus _VI_FUNC rsrtm_FetchWaveformConversionData (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViReal64 *xStart,
                                                     ViReal64 *xIncrement,
                                                     ViReal64 *yStart,
                                                     ViReal64 *yIncrement,
                                                     ViInt32 *yResolution);

ViStatus _VI_FUNC rsrtm_FetchEnvelopeWaveform (ViSession instrumentHandle,
                                               ViInt32 channel,
                                               ViInt32 waveformSize,
                                               ViReal64 _VI_FAR waveformArray[],
                                               ViInt32* actualPoints,
                                               ViReal64* initialX,
                                               ViReal64* xIncrement);
ViStatus _VI_FUNC rsrtm_FetchEnvelopeWaveformHeader (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViReal64* xStart,
                                                     ViReal64* xStop,
                                                     ViInt32* recordLength,
                                                     ViInt32* valuesPerSample);

ViStatus _VI_FUNC rsrtm_FetchEnvelopeWaveformConversionData (ViSession instrumentHandle,
                                                             ViInt32 channel,
                                                             ViReal64 *xStart,
                                                             ViReal64 *xIncrement,
                                                             ViReal64 *yStart,
                                                             ViReal64 *yIncrement,
                                                             ViInt32 *yResolution);

ViStatus _VI_FUNC rsrtm_FetchMathWaveform (ViSession instrumentHandle,
                                           ViInt32 mathNumber, ViInt32 waveformSize,
                                           ViReal64 _VI_FAR waveformArray[],
                                           ViInt32* actualPoints);
ViStatus _VI_FUNC rsrtm_FetchMathWaveformHeader (ViSession instrumentHandle,
                                                 ViInt32 mathNumber,
                                                 ViReal64* xStart, ViReal64* xStop,
                                                 ViInt32* recordLength,
                                                 ViInt32* valuesPerSample);

ViStatus _VI_FUNC rsrtm_FetchMathWaveformConversionData (ViSession instrumentHandle,
                                                         ViInt32 channel,
                                                         ViReal64 *xStart,
                                                         ViReal64 *xIncrement,
                                                         ViReal64 *yStart,
                                                         ViReal64 *yIncrement,
                                                         ViInt32 *yResolution);

ViStatus _VI_FUNC rsrtm_FetchReferenceWaveform (ViSession instrumentHandle,
                                                ViInt32 referenceWfm,
                                                ViInt32 waveformSize,
                                                ViReal64 _VI_FAR waveformArray[],
                                                ViInt32* actualPoints);
ViStatus _VI_FUNC rsrtm_FetchReferenceWaveformHeader (ViSession instrumentHandle,
                                                      ViInt32 referenceWfm,
                                                      ViReal64* xStart,
                                                      ViReal64* xStop,
                                                      ViInt32* recordLength,
                                                      ViInt32* valuesPerSample);

ViStatus _VI_FUNC rsrtm_FetchReferenceWaveformConversionData (ViSession instrumentHandle,
                                                              ViInt32 channel,
                                                              ViReal64 *xStart,
                                                              ViReal64 *xIncrement,
                                                              ViReal64 *yStart,
                                                              ViReal64 *yIncrement,
                                                              ViInt32 *yResolution);

ViStatus _VI_FUNC rsrtm_FetchMainWaveformMeasurement (ViSession instrumentHandle,
                                                      ViInt32 measurement,
                                                      ViInt32 measurementFunction,
                                                      ViReal64* measurementResult);
ViStatus _VI_FUNC rsrtm_Abort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_self_test (ViSession instrumentHandle,
                                   ViInt16* selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsrtm_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsrtm_error_query (ViSession instrumentHandle, ViInt32* errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsrtm_ErrorList (ViSession instrumentHandle, ViInt32 bufferSize,
                                   ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC rsrtm_error_message (ViSession instrumentHandle,
                                       ViStatus errorCode,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsrtm_ConfigureInstrumentName (ViSession instrumentHandle,
                                                 ViString name);
ViStatus _VI_FUNC rsrtm_ResetStatusRegisters (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_SetStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerType,
                                           ViInt32 statusRegister,
                                           ViInt32 registerPart,
                                           ViInt32 registerValue);
ViStatus _VI_FUNC rsrtm_GetStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerType,
                                           ViInt32 statusRegister,
                                           ViInt32 registerPart,
                                           ViInt32* registerValue);
ViStatus _VI_FUNC rsrtm_GetError (ViSession instrumentHandle, ViStatus* code,
                                  ViInt32 bufferSize, ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rsrtm_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rsrtm_WriteInstrData (ViSession instrumentHandle,
                                        ViChar _VI_FAR writeBuffer[]);
ViStatus _VI_FUNC rsrtm_ReadInstrData (ViSession instrumentHandle,
                                       ViInt32 numberOfBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViUInt32* numBytesRead);
ViStatus _VI_FUNC rsrtm_QueryViBoolean (ViSession instrumentHandle,
                                        ViString command, ViBoolean* value);
ViStatus _VI_FUNC rsrtm_QueryViInt32 (ViSession instrumentHandle, ViString command,
                                      ViInt32* value);
ViStatus _VI_FUNC rsrtm_QueryViReal64 (ViSession instrumentHandle, ViString command,
                                       ViReal64* value);
ViStatus _VI_FUNC rsrtm_QueryViString (ViSession instrumentHandle, ViString command,
                                       ViInt32 bufferSize, ViChar _VI_FAR value[]);
ViStatus _VI_FUNC rsrtm_FileManagerOperations (ViSession instrumentHandle,
                                               ViInt32 operation, ViString source,
                                               ViString destination);
ViStatus _VI_FUNC rsrtm_FileCount (ViSession instrumentHandle, ViString directory,
                                   ViInt32* numberOfFilesAndFolders);
ViStatus _VI_FUNC rsrtm_FileDirectoryContent (ViSession instrumentHandle,
                                              ViString directory,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR output[]);
ViStatus _VI_FUNC rsrtm_FileSubdirectoriesCount (ViSession instrumentHandle,
                                                 ViString directory,
                                                 ViInt32* numberOfSubdirectories);
ViStatus _VI_FUNC rsrtm_FileSubdirectories (ViSession instrumentHandle,
                                            ViString directory, ViInt32 bufferSize,
                                            ViChar _VI_FAR output[]);
ViStatus _VI_FUNC rsrtm_FileDrives (ViSession instrumentHandle, ViInt32 bufferSize,
                                    ViChar _VI_FAR output[]);
ViStatus _VI_FUNC rsrtm_ReadToFileFromInstrument (ViSession instrumentHandle,
                                                  ViString source,
                                                  ViString destination);
ViStatus _VI_FUNC rsrtm_WriteFromFileToInstrument (ViSession instrumentHandle,
                                                   ViString source,
                                                   ViString destination);
ViStatus _VI_FUNC rsrtm_DataSetFileOperations (ViSession instrumentHandle,
                                               ViInt32 operation,
                                               ViInt32 stateNumber, ViString path);
ViStatus _VI_FUNC rsrtm_close (ViSession instrumentHandle);

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSRTM_HEADER */



